/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalTabwrite.h"
#include "HvSignalVar.h"
#include "HvMath.h"
#include "HvControlUnop.h"
#include "HvControlCast.h"
#include "HvControlDelay.h"
#include "HvControlIf.h"
#include "HvControlVar.h"
#include "HvControlPack.h"
#include "HvControlSystem.h"
#include "HvControlRandom.h"
#include "HvSignalPhasor.h"
#include "HvControlSlice.h"
#include "HvSignalLine.h"
#include "HvControlTabhead.h"
#include "HvSignalTabread.h"
#include "HvSignalRPole.h"
#include "HvControlBinop.h"
#include "HvSignalDel1.h"
#include "HvTable.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_8NNRIa7Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QUfu7EPl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_1jAE3DCI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_A2gOZBfT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_exzTWxYQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IwHxtQok_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_BoFCiufk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_X61L4Xql_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fVKiztGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WDyGCps6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hBtVC1YN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_SGEStiVU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xbn03kxx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xvSpHPLk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_HIgk2fe9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_JZVqIjie_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_603mzska_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uBwgY87m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CpOWnaY2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_txo6JOJI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1f5JXOkO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XtqZbJey_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_54SvMGMJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_c4ZFi1xD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_q6kq3Ubp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_G8pthHmJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2fGU6gTw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NVMx3H8G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4k7hSCfQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jHzRnEmD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YWFVhKJ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0KUY8ZEO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_gCnHxj6p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dhf7tpHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q5EFCw8E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rniJcE7R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bt5A0mb7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sNq7I5Nm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SEfjl6L9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FtRYl4rc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uyCqeMWw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rBKep36M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E5H6yPG3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kLMaVwDN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XneGJasO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ZKo2XtQk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0EXbdyvH_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_ISVPd5rh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oWzL8J2N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QFRDVWci_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3fqi2kCS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G8zcBb43_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wxbRyfFo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gXDA5xkE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_m9t7RWei_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_un2dSYgb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EPBAxlMf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_avD4cbEi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Apwj17rY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cEkF4vBC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7z7pOrJN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0r5PDND8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mpKhiEz8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NSwzd9u9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_91jILYT4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_z6x2gNGK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_AuaYEc1M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_upzpxO1p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZzJJruCe_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_76Xj2iln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AtkJCIYl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CdLjn5lv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Xy8ya2tR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3lokLHSW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XHxOoCzk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uWQjPZ1j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tLaunBHK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hThsXw0k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_vrtdTNeb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_srckXUuK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_9NnXeF9p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_j51w71ej_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_7ccO1kzF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_1HM3i1EO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_QSCHG0IJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uAHzBCZj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vYv0ApE8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_47YUDVPL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_GZMCGtHc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iekFGMBF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UBoki3rG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_En6XCdb2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FU4oXBfB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0n2vnpT5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YkJlTFjL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V9koebQb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RS8ODQkm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_UBAUBOvl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UsMx4d56_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_HmpcaSDD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TApWqnzX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ejMao2K3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bi1YY0KK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_AooxjNXh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KRehpgxi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UBvK8YFZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LQeAk7KF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_d3bswzs0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eWx60uqF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q7VctYDq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jLra77Nw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wfeKkFrt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xOuT3Soj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rPi0Wngs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qZJRNmZH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nRTvxAbN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_mvgOoFRf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GETqy3XJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Xq7smW8A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_o2Go43DW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_c7D9aVPT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_h8FaH1rY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_3sWiG9ce_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xdFLddNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yL9mxAoK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j7eEbx4f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_LBAgLHsO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VH91JAg2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zkI8W812_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_laqWFmX0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z5skfGXF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tkj5DesW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o1r2bLPK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_864jUkBr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MoeAtNMe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_MebRHg9W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0MbOij7d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_6nZJ4UYk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MDpLXs8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ZPNQQZqj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_FLEg3Npi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_LGbwZp1r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2tAEBcWl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SeGqnnO8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Nk5fk44T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Qvkg0fYL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K3d4ETVZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5TI3d7lG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F4E5Pk94_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9FoCUWdl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xyoN98pQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Inw8F8Dg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bk6mwB1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ameKGybK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h5ZfUkyl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0z1QmoVZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_AtRccqw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_OEybK1Rs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_fvUeDhhF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_FMgXuaw3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_J14ZW1WJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4GXy3sYC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ukNBIjrS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pUB0qEgc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mnLzM7Cc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sLSdXp9p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wBtZDcez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3BtDYzQC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_DdGiUNQu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_YJ6Cn1mo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_I5DXKQcd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_f2ZJx0K6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_2ghCrVJ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_LI5YLypx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FnD4rgVb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tp8dAKnx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CzRppoT1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yqiNuYYi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GuA335rA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p8B1pUrO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dzkZizOd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_COgMuM1P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_nmVtwXef_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VYDrfIVK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qJ7ltNSt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_829e4Cxe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_CxkVjPhG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SdpojGFW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z7Nqeqhg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xOOufnOJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gMT5ylhp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Op6zmxUf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jU6hcS7t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1q5iAMK5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JDl72FGE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_4FlYFCJy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_klEDt1lK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DhnpOgKq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_nxZMyrob_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_8gOXB3xq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u9WdO9Qo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gZOVAsUo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tZIrO3Fq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2NL7SNMC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zfGU2lmI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3SEljIKK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_L03sZepT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_PQFiP9kx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WRwn5aCX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fQIZxBAO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_l18xolK5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5tUBN5BQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Q5NJoIXr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nQTFRM1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7KffNp2E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nGlfQVYA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_npwmuVmb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KPJjALpw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lDgPhFkm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yv9hOr3S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OqmMB7QP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NIqBN0fN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SE81RVtH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_O2He96s7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mGt2koja_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8H9Pj0Vm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZIM32DDV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Otal4Rm2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8PCiIGTc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_clkx5YQB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ZUBHcdlZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HqxfuSUf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_stelZnfB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_SOnKytj4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5rpRIrCT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bKk0j5zi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DP9edkKn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6xeWq5pG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zPm56Ibu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LvzQaRPi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_1gMbtVIf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F30VkCpd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_s2yBO4nD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_voeK0Cvo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_OplJ2uFu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_s9bvGrqQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_wTihnYjl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rNLmOMtV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pH0W8QKE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cAEYCNPR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_LqSnI6A1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lEOmiRZG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WsEgbcUx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V9SZxp8C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kfeORq0g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dDPBuqA8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y2CjZXMT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qSiqonNN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CM4Y2uds_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rrqvLkjB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_sOY0UMp3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Wi2qnehE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_8vL8PQ4v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_yX2xNQkK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_4CMEPGf8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_iwhjOLJz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Re1HtqoA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cx1RYuJZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A3RUd5eu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zbNdt9jA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xR0cDi5u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2Qi69lhR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_2VtX2nvk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8YbGCUlP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zM6vqNah_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hNop4w4J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_KTYdMnby_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_DCEXeQKq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_qE08cZ0T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5XoU9BKQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qLRWy8iA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1OJv3Nw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_AKXgCfC9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L5VGwijs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xJFvzWjq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AfTfWCFT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i4SpdSmp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R4ECF7Lk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xcW4csNj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NolNXImP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K3CDsduV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p5kKzdGx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_szT3G6yP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_RIoiCsKD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2xiwqzBb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MelOFGZf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_IKhOwbUn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_bfZIbUE2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZWfoHn1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yMCEv1VJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yFLUGUR1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ps7QSi2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2buiJBga_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A5Gdkem4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_KuKDDAKy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kBF5yQkO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_axPRnUMZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iBlM2YNM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_LbHAWdME_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_CpwvU6KN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_hafWPAXo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aEpMn5JC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YsWkTQoP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7XSWL722_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xMWwFzhl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_13VRMCoE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RorDRZuo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bNCQmAZS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3xvi27y3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iZFFWzBQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h2Ho9R6p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8KEEhMJ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I8z6SLTZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8DS3aw8V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_t0H66Mbe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_JUL9vMrs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_RzRqe8NU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_P5MZlRF8_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_UClYYb9p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_aZFFfkGW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oYQFKZEp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9w2rNrSm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sVfqzkyD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PUOXQzEP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mV91JZ9F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GQVTb9gc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_veAemnHH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LWjZxpYR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_B8h8HFPF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QCLevWjb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_h4KcIh6W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ZcYu1EdJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_4IVa2Ccu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SJNIBe5O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QYXN3E0r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cnKVz9C0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_MuSqpD9i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5PZGeM1O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fAWeyVY5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hNEqMpan_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aW6m2UZZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WIKs3k0N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C1yIgzfA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xh42LTo3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y6rpm4bq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Cdyjl7D8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JFHJjIlv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_C6MCOhE1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hOOeF0PL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WuPXm2jV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_ArPdA94j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_vPDozOK1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NOitcVsp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oShllf7X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_83WOeBlz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AWecYxmp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KWy6EVPH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7qE1Z631_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_rGnPWbvR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XFARZ4Gc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pYawC592_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jbI9yj8g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_9KR5KSd4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_wajJqACn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Lq4BFU9g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KYxLqhHI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9Zw9p5RU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GfEfYOvP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VeKuXy28_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l4DrZ9I8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HN2PVYfG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r7AAEg9A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Nb4R9Ux3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1NIF3SlV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sx5lKXi5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vw8WsQxj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tEqTAEoW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pRU39nXs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_GO4WYY8L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_FdPMOmen_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_eaJ4cG0Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YGVvd4gh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_066Nvgr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_txUpzsPV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OJEXY2xw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MFVqNLkU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uhYsQNmZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9XpjrCrO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7NYRtneE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rP2jzXlA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_1wfFsth5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c0JXtzfx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_IVUKow9t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_P7oOt6IS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_tAVQTxnX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_6DMPrPpa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_OkwVgRT5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QPh0vIJm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XXooLmny_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PxFxd5Tz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qLSwvCyt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xNNA3uRd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iQKtLgvI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VbkTr6Gl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pWUKyF8S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gxP7tdhj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g8OCs4wM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IgX2paaP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_khn7ywX0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0Br73mqd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BCpIrUv0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_5PGVfP3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Sosyff7K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eyh4mbJR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SjB86Zjs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f5JM40rC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bXJfiFGP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DXMOh2As_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rD1pyelN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6qRRk8SY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uWvGw9Tn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mFtGvgxo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QRxcZW1Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_b6CppYNU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cxZZMx5J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ttDPDEmP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kaljJ13k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cQcXuNX1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FspE89af_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YxXQ7j8s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_j4QpksgS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZheHodIV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fmMu1o7G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hBUEOzfB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MWyRwxOA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y6Sp4j4v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WtNe21VV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L07ySDIJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eNo26pLt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zmraf37m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oep2mXqM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nHF8GeFh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gB6n6uLL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7hAJWwub_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_x1nWPBEA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BELnjGB1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4yoEobQi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_szoXvEX4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hSakqM93_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nH5084De_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fE1Yi9kt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zamNuggz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2AyaEYOj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_o5OfGGrB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RrBeYUmS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jGLoaRTN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_viL8WLxs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hhgbF70R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qRi6Ewad_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UvvvUMqb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Elf8qhLV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ZSlQ9OCu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_IPrnNLZb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_A2JOg15Y_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_HXM0zpT1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_JAMez6mH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MJbZj0ay_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Wz0Z02U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sVyQPEUK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5IfDCwMl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BCTDBvCA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9UTl8pUL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_U0UHf1yz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MszV3MGJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QXlcIyOC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_elqioPSN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_M1C8TJbm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_nf9MXItr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_cwhz8vis_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L1rGFrrx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TQEyuIbl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ygznpXmp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_eOKNwV0d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L3qofHDY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IkPUpR24_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EG040oDP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yKe8bL0k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5ETuaHxH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LGevCkzp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JkpeHpZw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4ByjD5JE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_QETJjNCt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_2X5jHmJz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kXBD1Iql_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sgXmrm5G_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_HOYIG19r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TtaVeKkP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_T0YoAxYO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BdVYQilN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_54ndX7JH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yTg8OlgU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_vTJ5QNJB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Pht8jFiv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SzQQ5bpu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2L94DwVk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MQew5eT6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xa7iulBC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_bH8NVIL5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_AbU2pxTx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qCWBLwYs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CO4pbqqR_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_cg3iAZsb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_lxAfixgD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TZaQ4lMH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vcOhUZPs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h27BpH2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ufdoxtmh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hwkBv5n6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AQZ9w47z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_d5gtlF5l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QBoDI2NG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7DY1HdZE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LxqzgTxs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_x5dnksIx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WuQs2qI7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x6IfLyUi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lL8JFIiY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_niAFxcPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TTGdZrAC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fwkTBKn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_phssu0qR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eNYgAauy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BSlSwIm3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WiXLEDr9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HuVE1Axr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hudb3tQE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0gPy52HJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ltOQhE6m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WVZpahDh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hZv5wG4u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3zlXojcy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GwhmgjKE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rr5vawxG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U5RXwR5x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hi5UD8C0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u1AtTQNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sDT4WqNP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DWUmewii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o43cIf42_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IkQNF3ti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MFKySz1y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ENm51JDy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V0V4NzNH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cuHHyBjo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k8eJrMoV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RbSQ5mVg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LyZiIu9C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O1PxUCko_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f798wv8y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cED0GubQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Stzdv9zw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y5jACfnX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VKX7tySQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h0JAdqMi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JeM1FE3d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3eBKxwqB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_faSJprqN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cvTkUjLH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BCHPEheV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r2iHQImZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nhcP1KJB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qzJf6JPu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RWrJN7yj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_g9nB60eR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_y89s2KcE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Np88CS64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hcR6sVxJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LptUNHrb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UXF8HLKT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rCTKJLa3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3S76Dqtw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UJYKIeBu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3zQ4OCSA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iZedKVwx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JrThWtRQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dTLssDxs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GG0nQnZM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hIj3NGVN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yM8UVwgE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PhB6hpe2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kOZMDCap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_un3WBGgJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lB4cQQoV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vcYOh2sI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_W3bUhQDw_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_XP3gf8Xc;
  SignalLine sLine_W0S3zo6T;
  SignalLine sLine_pt55X9SE;
  SignalTabhead sTabhead_SyekcpK0;
  SignalTabread sTabread_sUPQOFs0;
  SignalTabread sTabread_91VkU3O8;
  SignalTabhead sTabhead_OmYRX0J9;
  SignalTabread sTabread_yGtZyqPp;
  SignalTabread sTabread_mlhDATqp;
  SignalTabwrite sTabwrite_G7GNzQsX;
  SignalRPole sRPole_TN6XmZqs;
  SignalDel1 sDel1_GiFdu9KP;
  SignalTabread sTabread_cwhz8vis;
  SignalTabwrite sTabwrite_9jHfFD4s;
  SignalTabread sTabread_QSCHG0IJ;
  SignalRPole sRPole_xkEzwnNR;
  SignalLine sLine_84YJHH5v;
  SignalLine sLine_F4Qdw6P6;
  SignalTabread sTabread_wTihnYjl;
  SignalTabread sTabread_qE08cZ0T;
  SignalTabread sTabread_hafWPAXo;
  SignalTabread sTabread_4IVa2Ccu;
  SignalTabread sTabread_OkwVgRT5;
  SignalTabread sTabread_Lq4BFU9g;
  SignalTabwrite sTabwrite_4d2bpFph;
  SignalTabwrite sTabwrite_xADlMFnm;
  SignalTabwrite sTabwrite_H1ADYMjs;
  SignalTabwrite sTabwrite_3Dra1G18;
  SignalTabwrite sTabwrite_DDd7aiF4;
  SignalTabwrite sTabwrite_Jnxbzqrv;
  SignalTabread sTabread_AooxjNXh;
  SignalRPole sRPole_gxOvrWN8;
  SignalTabread sTabread_3sWiG9ce;
  SignalRPole sRPole_ls7iDhAw;
  SignalTabread sTabread_LGbwZp1r;
  SignalRPole sRPole_qbURdhk3;
  SignalTabwrite sTabwrite_F3uA3heL;
  SignalTabwrite sTabwrite_VvCDIds8;
  SignalTabwrite sTabwrite_qwpoaRyi;
  SignalTabwrite sTabwrite_4C14w19W;
  SignalLine sLine_LgBv0MbP;
  ControlVar cVar_8NNRIa7Y;
  ControlVar cVar_QUfu7EPl;
  ControlPack cPack_1jAE3DCI;
  ControlBinop cBinop_exzTWxYQ;
  ControlVar cVar_IwHxtQok;
  ControlPack cPack_BoFCiufk;
  ControlVar cVar_X61L4Xql;
  ControlVar cVar_fVKiztGD;
  ControlDelay cDelay_SGEStiVU;
  ControlDelay cDelay_xbn03kxx;
  ControlBinop cBinop_HIgk2fe9;
  HvTable hTable_JZVqIjie;
  ControlBinop cBinop_uBwgY87m;
  ControlVar cVar_q6kq3Ubp;
  ControlBinop cBinop_2fGU6gTw;
  ControlBinop cBinop_4k7hSCfQ;
  SignalVarf sVarf_lyO5EoeL;
  SignalVarf sVarf_27eG82Sn;
  SignalVarf sVarf_BU9Bd5lz;
  ControlVar cVar_0KUY8ZEO;
  ControlBinop cBinop_Dhf7tpHd;
  ControlBinop cBinop_rniJcE7R;
  SignalVarf sVarf_wzhbASVN;
  SignalVarf sVarf_Uz0pXEA5;
  SignalVarf sVarf_vSvusw1r;
  ControlBinop cBinop_Bt5A0mb7;
  ControlBinop cBinop_sNq7I5Nm;
  ControlBinop cBinop_uyCqeMWw;
  ControlBinop cBinop_rBKep36M;
  ControlBinop cBinop_E5H6yPG3;
  ControlBinop cBinop_kLMaVwDN;
  ControlBinop cBinop_XneGJasO;
  ControlBinop cBinop_3fqi2kCS;
  ControlBinop cBinop_G8zcBb43;
  SignalVarf sVarf_ViOOKQ9O;
  ControlVar cVar_wxbRyfFo;
  ControlBinop cBinop_un2dSYgb;
  ControlBinop cBinop_EPBAxlMf;
  ControlBinop cBinop_Apwj17rY;
  ControlBinop cBinop_cEkF4vBC;
  ControlBinop cBinop_7z7pOrJN;
  ControlBinop cBinop_0r5PDND8;
  ControlBinop cBinop_mpKhiEz8;
  SignalVarf sVarf_U3gUg70q;
  ControlBinop cBinop_91jILYT4;
  ControlRandom cRandom_AuaYEc1M;
  ControlSlice cSlice_upzpxO1p;
  ControlDelay cDelay_76Xj2iln;
  ControlVar cVar_3lokLHSW;
  ControlBinop cBinop_uWQjPZ1j;
  ControlBinop cBinop_tLaunBHK;
  ControlBinop cBinop_hThsXw0k;
  ControlTabhead cTabhead_vrtdTNeb;
  ControlVar cVar_j51w71ej;
  ControlDelay cDelay_7ccO1kzF;
  ControlDelay cDelay_1HM3i1EO;
  ControlBinop cBinop_uAHzBCZj;
  ControlBinop cBinop_vYv0ApE8;
  ControlBinop cBinop_47YUDVPL;
  ControlBinop cBinop_FU4oXBfB;
  ControlBinop cBinop_YkJlTFjL;
  ControlBinop cBinop_V9koebQb;
  ControlTabhead cTabhead_UBAUBOvl;
  ControlVar cVar_TApWqnzX;
  ControlDelay cDelay_ejMao2K3;
  ControlDelay cDelay_bi1YY0KK;
  ControlBinop cBinop_KRehpgxi;
  ControlBinop cBinop_UBvK8YFZ;
  ControlBinop cBinop_LQeAk7KF;
  ControlBinop cBinop_wfeKkFrt;
  ControlBinop cBinop_rPi0Wngs;
  ControlBinop cBinop_qZJRNmZH;
  ControlTabhead cTabhead_mvgOoFRf;
  ControlVar cVar_o2Go43DW;
  ControlDelay cDelay_c7D9aVPT;
  ControlDelay cDelay_h8FaH1rY;
  ControlBinop cBinop_xdFLddNR;
  ControlBinop cBinop_yL9mxAoK;
  ControlBinop cBinop_j7eEbx4f;
  ControlBinop cBinop_z5skfGXF;
  ControlBinop cBinop_o1r2bLPK;
  ControlBinop cBinop_864jUkBr;
  ControlTabhead cTabhead_MebRHg9W;
  ControlVar cVar_MDpLXs8q;
  ControlDelay cDelay_ZPNQQZqj;
  ControlDelay cDelay_FLEg3Npi;
  ControlBinop cBinop_2tAEBcWl;
  ControlBinop cBinop_SeGqnnO8;
  ControlBinop cBinop_Nk5fk44T;
  ControlBinop cBinop_9FoCUWdl;
  ControlBinop cBinop_Inw8F8Dg;
  ControlBinop cBinop_Bk6mwB1s;
  ControlDelay cDelay_AtRccqw0;
  ControlDelay cDelay_OEybK1Rs;
  ControlBinop cBinop_FMgXuaw3;
  HvTable hTable_J14ZW1WJ;
  ControlBinop cBinop_ukNBIjrS;
  ControlDelay cDelay_YJ6Cn1mo;
  ControlDelay cDelay_I5DXKQcd;
  ControlBinop cBinop_2ghCrVJ6;
  HvTable hTable_LI5YLypx;
  ControlBinop cBinop_tp8dAKnx;
  ControlDelay cDelay_nmVtwXef;
  ControlDelay cDelay_VYDrfIVK;
  ControlBinop cBinop_829e4Cxe;
  HvTable hTable_CxkVjPhG;
  ControlBinop cBinop_z7Nqeqhg;
  ControlDelay cDelay_4FlYFCJy;
  ControlDelay cDelay_klEDt1lK;
  ControlBinop cBinop_nxZMyrob;
  HvTable hTable_8gOXB3xq;
  ControlBinop cBinop_gZOVAsUo;
  ControlPack cPack_L03sZepT;
  ControlPack cPack_PQFiP9kx;
  ControlBinop cBinop_WRwn5aCX;
  ControlBinop cBinop_fQIZxBAO;
  ControlVar cVar_l18xolK5;
  ControlBinop cBinop_nQTFRM1s;
  ControlBinop cBinop_7KffNp2E;
  SignalVarf sVarf_5YmX3rzA;
  ControlBinop cBinop_npwmuVmb;
  ControlBinop cBinop_KPJjALpw;
  ControlBinop cBinop_lDgPhFkm;
  SignalVarf sVarf_6KEKAhKT;
  ControlVar cVar_yv9hOr3S;
  ControlVar cVar_OqmMB7QP;
  ControlVar cVar_NIqBN0fN;
  ControlVar cVar_SE81RVtH;
  ControlIf cIf_O2He96s7;
  ControlBinop cBinop_mGt2koja;
  ControlBinop cBinop_8H9Pj0Vm;
  ControlBinop cBinop_ZIM32DDV;
  ControlDelay cDelay_clkx5YQB;
  ControlDelay cDelay_ZUBHcdlZ;
  ControlBinop cBinop_stelZnfB;
  HvTable hTable_SOnKytj4;
  ControlBinop cBinop_bKk0j5zi;
  ControlTabhead cTabhead_1gMbtVIf;
  ControlVar cVar_voeK0Cvo;
  ControlDelay cDelay_OplJ2uFu;
  ControlDelay cDelay_s9bvGrqQ;
  ControlBinop cBinop_rNLmOMtV;
  ControlBinop cBinop_pH0W8QKE;
  ControlBinop cBinop_cAEYCNPR;
  ControlBinop cBinop_kfeORq0g;
  ControlBinop cBinop_y2CjZXMT;
  ControlBinop cBinop_qSiqonNN;
  ControlDelay cDelay_Wi2qnehE;
  ControlDelay cDelay_8vL8PQ4v;
  ControlBinop cBinop_4CMEPGf8;
  HvTable hTable_iwhjOLJz;
  ControlBinop cBinop_cx1RYuJZ;
  ControlTabhead cTabhead_2VtX2nvk;
  ControlVar cVar_hNop4w4J;
  ControlDelay cDelay_KTYdMnby;
  ControlDelay cDelay_DCEXeQKq;
  ControlBinop cBinop_5XoU9BKQ;
  ControlBinop cBinop_qLRWy8iA;
  ControlBinop cBinop_1OJv3Nw0;
  ControlBinop cBinop_i4SpdSmp;
  ControlBinop cBinop_xcW4csNj;
  ControlBinop cBinop_NolNXImP;
  ControlDelay cDelay_RIoiCsKD;
  ControlDelay cDelay_2xiwqzBb;
  ControlBinop cBinop_IKhOwbUn;
  HvTable hTable_bfZIbUE2;
  ControlBinop cBinop_yMCEv1VJ;
  ControlTabhead cTabhead_KuKDDAKy;
  ControlVar cVar_iBlM2YNM;
  ControlDelay cDelay_LbHAWdME;
  ControlDelay cDelay_CpwvU6KN;
  ControlBinop cBinop_aEpMn5JC;
  ControlBinop cBinop_YsWkTQoP;
  ControlBinop cBinop_7XSWL722;
  ControlBinop cBinop_3xvi27y3;
  ControlBinop cBinop_h2Ho9R6p;
  ControlBinop cBinop_8KEEhMJ1;
  ControlDelay cDelay_JUL9vMrs;
  ControlDelay cDelay_RzRqe8NU;
  ControlBinop cBinop_UClYYb9p;
  HvTable hTable_aZFFfkGW;
  ControlBinop cBinop_9w2rNrSm;
  ControlTabhead cTabhead_veAemnHH;
  ControlVar cVar_QCLevWjb;
  ControlDelay cDelay_h4KcIh6W;
  ControlDelay cDelay_ZcYu1EdJ;
  ControlBinop cBinop_SJNIBe5O;
  ControlBinop cBinop_QYXN3E0r;
  ControlBinop cBinop_cnKVz9C0;
  ControlBinop cBinop_aW6m2UZZ;
  ControlBinop cBinop_C1yIgzfA;
  ControlBinop cBinop_xh42LTo3;
  ControlDelay cDelay_C6MCOhE1;
  ControlDelay cDelay_hOOeF0PL;
  ControlBinop cBinop_ArPdA94j;
  HvTable hTable_vPDozOK1;
  ControlBinop cBinop_oShllf7X;
  ControlTabhead cTabhead_rGnPWbvR;
  ControlVar cVar_jbI9yj8g;
  ControlDelay cDelay_9KR5KSd4;
  ControlDelay cDelay_wajJqACn;
  ControlBinop cBinop_KYxLqhHI;
  ControlBinop cBinop_9Zw9p5RU;
  ControlBinop cBinop_GfEfYOvP;
  ControlBinop cBinop_Nb4R9Ux3;
  ControlBinop cBinop_sx5lKXi5;
  ControlBinop cBinop_Vw8WsQxj;
  ControlDelay cDelay_FdPMOmen;
  ControlDelay cDelay_eaJ4cG0Y;
  ControlBinop cBinop_066Nvgr5;
  HvTable hTable_txUpzsPV;
  ControlBinop cBinop_MFVqNLkU;
  ControlTabhead cTabhead_1wfFsth5;
  ControlVar cVar_P7oOt6IS;
  ControlDelay cDelay_tAVQTxnX;
  ControlDelay cDelay_6DMPrPpa;
  ControlBinop cBinop_QPh0vIJm;
  ControlBinop cBinop_XXooLmny;
  ControlBinop cBinop_PxFxd5Tz;
  ControlBinop cBinop_pWUKyF8S;
  ControlBinop cBinop_g8OCs4wM;
  ControlBinop cBinop_IgX2paaP;
  ControlVar cVar_0Br73mqd;
  ControlVar cVar_BCpIrUv0;
  ControlPack cPack_5PGVfP3j;
  ControlVar cVar_Sosyff7K;
  ControlBinop cBinop_f5JM40rC;
  ControlBinop cBinop_bXJfiFGP;
  SignalVarf sVarf_rlnKNXuQ;
  ControlBinop cBinop_rD1pyelN;
  ControlBinop cBinop_6qRRk8SY;
  ControlBinop cBinop_uWvGw9Tn;
  SignalVarf sVarf_A4lRuYRx;
  ControlVar cVar_mFtGvgxo;
  ControlBinop cBinop_cxZZMx5J;
  ControlBinop cBinop_ttDPDEmP;
  SignalVarf sVarf_JIzMvRoq;
  ControlBinop cBinop_cQcXuNX1;
  ControlBinop cBinop_FspE89af;
  ControlBinop cBinop_YxXQ7j8s;
  SignalVarf sVarf_vruzbMdq;
  ControlVar cVar_j4QpksgS;
  ControlBinop cBinop_hBUEOzfB;
  ControlBinop cBinop_MWyRwxOA;
  SignalVarf sVarf_qpdtmYPX;
  ControlBinop cBinop_WtNe21VV;
  ControlBinop cBinop_L07ySDIJ;
  ControlBinop cBinop_eNo26pLt;
  SignalVarf sVarf_MwTAystm;
  ControlBinop cBinop_Zmraf37m;
  ControlBinop cBinop_nHF8GeFh;
  ControlBinop cBinop_gB6n6uLL;
  ControlDelay cDelay_x1nWPBEA;
  ControlVar cVar_hSakqM93;
  ControlBinop cBinop_fE1Yi9kt;
  ControlBinop cBinop_zamNuggz;
  ControlBinop cBinop_2AyaEYOj;
  ControlVar cVar_o5OfGGrB;
  ControlVar cVar_RrBeYUmS;
  ControlIf cIf_hhgbF70R;
  ControlBinop cBinop_qRi6Ewad;
  ControlDelay cDelay_ZSlQ9OCu;
  ControlDelay cDelay_IPrnNLZb;
  ControlBinop cBinop_HXM0zpT1;
  HvTable hTable_JAMez6mH;
  ControlBinop cBinop_2Wz0Z02U;
  ControlTabhead cTabhead_U0UHf1yz;
  ControlVar cVar_elqioPSN;
  ControlDelay cDelay_M1C8TJbm;
  ControlDelay cDelay_nf9MXItr;
  ControlBinop cBinop_L1rGFrrx;
  ControlBinop cBinop_TQEyuIbl;
  ControlBinop cBinop_ygznpXmp;
  ControlBinop cBinop_yKe8bL0k;
  ControlBinop cBinop_LGevCkzp;
  ControlBinop cBinop_JkpeHpZw;
  ControlVar cVar_kXBD1Iql;
  ControlVar cVar_TtaVeKkP;
  ControlVar cVar_T0YoAxYO;
  ControlVar cVar_BdVYQilN;
  ControlVar cVar_54ndX7JH;
  ControlVar cVar_yTg8OlgU;
  ControlIf cIf_SzQQ5bpu;
  ControlBinop cBinop_2L94DwVk;
  ControlVar cVar_MQew5eT6;
  ControlIf cIf_AbU2pxTx;
  ControlBinop cBinop_qCWBLwYs;
  ControlSlice cSlice_cg3iAZsb;
  ControlSlice cSlice_lxAfixgD;
  ControlVar cVar_TZaQ4lMH;
  ControlIf cIf_vcOhUZPs;
  ControlBinop cBinop_hwkBv5n6;
  ControlIf cIf_QBoDI2NG;
  ControlIf cIf_7DY1HdZE;
  ControlIf cIf_LxqzgTxs;
  ControlIf cIf_x5dnksIx;
  ControlIf cIf_WuQs2qI7;
  SignalVarf sVarf_Du99ZcVc;
  ControlBinop cBinop_fwkTBKn8;
  ControlBinop cBinop_phssu0qR;
  ControlBinop cBinop_BSlSwIm3;
  ControlBinop cBinop_WiXLEDr9;
  SignalVarf sVarf_XTMT3cTY;
  ControlBinop cBinop_hudb3tQE;
  ControlBinop cBinop_0gPy52HJ;
  SignalVarf sVarf_Bb40zEgq;
  SignalVarf sVarf_U4QKwSCH;
  ControlBinop cBinop_GwhmgjKE;
  ControlBinop cBinop_rr5vawxG;
  ControlBinop cBinop_U5RXwR5x;
  ControlBinop cBinop_Hi5UD8C0;
  ControlBinop cBinop_sDT4WqNP;
  ControlBinop cBinop_DWUmewii;
  ControlBinop cBinop_o43cIf42;
  ControlBinop cBinop_IkQNF3ti;
  ControlBinop cBinop_ENm51JDy;
  ControlBinop cBinop_V0V4NzNH;
  ControlBinop cBinop_cuHHyBjo;
  ControlBinop cBinop_JeM1FE3d;
  ControlBinop cBinop_3eBKxwqB;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
