/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_XP3gf8Xc, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_W0S3zo6T);
  numBytes += sLine_init(&sLine_pt55X9SE);
  numBytes += sTabhead_init(&sTabhead_SyekcpK0, &hTable_JZVqIjie);
  numBytes += sTabread_init(&sTabread_sUPQOFs0, &hTable_JZVqIjie, false);
  numBytes += sTabread_init(&sTabread_91VkU3O8, &hTable_JZVqIjie, false);
  numBytes += sTabhead_init(&sTabhead_OmYRX0J9, &hTable_JZVqIjie);
  numBytes += sTabread_init(&sTabread_yGtZyqPp, &hTable_JZVqIjie, false);
  numBytes += sTabread_init(&sTabread_mlhDATqp, &hTable_JZVqIjie, false);
  numBytes += sTabwrite_init(&sTabwrite_G7GNzQsX, &hTable_JZVqIjie);
  numBytes += sRPole_init(&sRPole_TN6XmZqs);
  numBytes += sDel1_init(&sDel1_GiFdu9KP);
  numBytes += sTabread_init(&sTabread_cwhz8vis, &hTable_JAMez6mH, true);
  numBytes += sTabwrite_init(&sTabwrite_9jHfFD4s, &hTable_JAMez6mH);
  numBytes += sTabread_init(&sTabread_QSCHG0IJ, &hTable_J14ZW1WJ, true);
  numBytes += sRPole_init(&sRPole_xkEzwnNR);
  numBytes += sLine_init(&sLine_84YJHH5v);
  numBytes += sLine_init(&sLine_F4Qdw6P6);
  numBytes += sTabread_init(&sTabread_wTihnYjl, &hTable_SOnKytj4, true);
  numBytes += sTabread_init(&sTabread_qE08cZ0T, &hTable_iwhjOLJz, true);
  numBytes += sTabread_init(&sTabread_hafWPAXo, &hTable_bfZIbUE2, true);
  numBytes += sTabread_init(&sTabread_4IVa2Ccu, &hTable_aZFFfkGW, true);
  numBytes += sTabread_init(&sTabread_OkwVgRT5, &hTable_txUpzsPV, true);
  numBytes += sTabread_init(&sTabread_Lq4BFU9g, &hTable_vPDozOK1, true);
  numBytes += sTabwrite_init(&sTabwrite_4d2bpFph, &hTable_SOnKytj4);
  numBytes += sTabwrite_init(&sTabwrite_xADlMFnm, &hTable_iwhjOLJz);
  numBytes += sTabwrite_init(&sTabwrite_H1ADYMjs, &hTable_bfZIbUE2);
  numBytes += sTabwrite_init(&sTabwrite_3Dra1G18, &hTable_aZFFfkGW);
  numBytes += sTabwrite_init(&sTabwrite_DDd7aiF4, &hTable_vPDozOK1);
  numBytes += sTabwrite_init(&sTabwrite_Jnxbzqrv, &hTable_txUpzsPV);
  numBytes += sTabread_init(&sTabread_AooxjNXh, &hTable_LI5YLypx, true);
  numBytes += sRPole_init(&sRPole_gxOvrWN8);
  numBytes += sTabread_init(&sTabread_3sWiG9ce, &hTable_CxkVjPhG, true);
  numBytes += sRPole_init(&sRPole_ls7iDhAw);
  numBytes += sTabread_init(&sTabread_LGbwZp1r, &hTable_8gOXB3xq, true);
  numBytes += sRPole_init(&sRPole_qbURdhk3);
  numBytes += sTabwrite_init(&sTabwrite_F3uA3heL, &hTable_J14ZW1WJ);
  numBytes += sTabwrite_init(&sTabwrite_VvCDIds8, &hTable_LI5YLypx);
  numBytes += sTabwrite_init(&sTabwrite_qwpoaRyi, &hTable_CxkVjPhG);
  numBytes += sTabwrite_init(&sTabwrite_4C14w19W, &hTable_8gOXB3xq);
  numBytes += sLine_init(&sLine_LgBv0MbP);
  numBytes += cVar_init_f(&cVar_8NNRIa7Y, 0.0f);
  numBytes += cVar_init_f(&cVar_QUfu7EPl, 0.0f);
  numBytes += cPack_init(&cPack_1jAE3DCI, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_IwHxtQok, 0.0f);
  numBytes += cPack_init(&cPack_BoFCiufk, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_X61L4Xql, 0.0f);
  numBytes += cVar_init_f(&cVar_fVKiztGD, 0.0f);
  numBytes += cDelay_init(this, &cDelay_SGEStiVU, 0.0f);
  numBytes += cDelay_init(this, &cDelay_xbn03kxx, 0.0f);
  numBytes += hTable_init(&hTable_JZVqIjie, 256);
  numBytes += cVar_init_s(&cVar_q6kq3Ubp, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_lyO5EoeL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_27eG82Sn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BU9Bd5lz, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_0KUY8ZEO, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_wzhbASVN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Uz0pXEA5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vSvusw1r, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_Bt5A0mb7, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_ViOOKQ9O, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_wxbRyfFo, 0.0f);
  numBytes += cBinop_init(&cBinop_mpKhiEz8, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_U3gUg70q, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_AuaYEc1M, 474594406);
  numBytes += cSlice_init(&cSlice_upzpxO1p, 1, 1);
  numBytes += cDelay_init(this, &cDelay_76Xj2iln, 0.0f);
  numBytes += cVar_init_f(&cVar_3lokLHSW, 5.0f);
  numBytes += cBinop_init(&cBinop_hThsXw0k, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_vrtdTNeb, &hTable_J14ZW1WJ);
  numBytes += cVar_init_s(&cVar_j51w71ej, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_7ccO1kzF, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_1HM3i1EO, 0.0f);
  numBytes += cBinop_init(&cBinop_uAHzBCZj, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_47YUDVPL, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_FU4oXBfB, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_V9koebQb, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_UBAUBOvl, &hTable_LI5YLypx);
  numBytes += cVar_init_s(&cVar_TApWqnzX, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_ejMao2K3, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_bi1YY0KK, 0.0f);
  numBytes += cBinop_init(&cBinop_KRehpgxi, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_LQeAk7KF, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_wfeKkFrt, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_qZJRNmZH, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_mvgOoFRf, &hTable_CxkVjPhG);
  numBytes += cVar_init_s(&cVar_o2Go43DW, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_c7D9aVPT, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_h8FaH1rY, 0.0f);
  numBytes += cBinop_init(&cBinop_xdFLddNR, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_j7eEbx4f, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_z5skfGXF, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_864jUkBr, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_MebRHg9W, &hTable_8gOXB3xq);
  numBytes += cVar_init_s(&cVar_MDpLXs8q, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_ZPNQQZqj, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_FLEg3Npi, 0.0f);
  numBytes += cBinop_init(&cBinop_2tAEBcWl, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_Nk5fk44T, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_9FoCUWdl, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Bk6mwB1s, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_AtRccqw0, 0.0f);
  numBytes += cDelay_init(this, &cDelay_OEybK1Rs, 0.0f);
  numBytes += hTable_init(&hTable_J14ZW1WJ, 256);
  numBytes += cDelay_init(this, &cDelay_YJ6Cn1mo, 0.0f);
  numBytes += cDelay_init(this, &cDelay_I5DXKQcd, 0.0f);
  numBytes += hTable_init(&hTable_LI5YLypx, 256);
  numBytes += cDelay_init(this, &cDelay_nmVtwXef, 0.0f);
  numBytes += cDelay_init(this, &cDelay_VYDrfIVK, 0.0f);
  numBytes += hTable_init(&hTable_CxkVjPhG, 256);
  numBytes += cDelay_init(this, &cDelay_4FlYFCJy, 0.0f);
  numBytes += cDelay_init(this, &cDelay_klEDt1lK, 0.0f);
  numBytes += hTable_init(&hTable_8gOXB3xq, 256);
  numBytes += cPack_init(&cPack_L03sZepT, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_PQFiP9kx, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_l18xolK5, 22050.0f);
  numBytes += cBinop_init(&cBinop_nQTFRM1s, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_5YmX3rzA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6KEKAhKT, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_yv9hOr3S, 0.0f);
  numBytes += cVar_init_f(&cVar_OqmMB7QP, 0.0f);
  numBytes += cVar_init_f(&cVar_NIqBN0fN, 0.0f);
  numBytes += cVar_init_f(&cVar_SE81RVtH, 0.0f);
  numBytes += cIf_init(&cIf_O2He96s7, false);
  numBytes += cDelay_init(this, &cDelay_clkx5YQB, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ZUBHcdlZ, 0.0f);
  numBytes += hTable_init(&hTable_SOnKytj4, 256);
  numBytes += cTabhead_init(&cTabhead_1gMbtVIf, &hTable_SOnKytj4);
  numBytes += cVar_init_s(&cVar_voeK0Cvo, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_OplJ2uFu, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_s9bvGrqQ, 0.0f);
  numBytes += cBinop_init(&cBinop_rNLmOMtV, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_cAEYCNPR, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_kfeORq0g, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_qSiqonNN, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_Wi2qnehE, 0.0f);
  numBytes += cDelay_init(this, &cDelay_8vL8PQ4v, 0.0f);
  numBytes += hTable_init(&hTable_iwhjOLJz, 256);
  numBytes += cTabhead_init(&cTabhead_2VtX2nvk, &hTable_iwhjOLJz);
  numBytes += cVar_init_s(&cVar_hNop4w4J, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_KTYdMnby, 25.796f);
  numBytes += cDelay_init(this, &cDelay_DCEXeQKq, 0.0f);
  numBytes += cBinop_init(&cBinop_5XoU9BKQ, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_1OJv3Nw0, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_i4SpdSmp, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_NolNXImP, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_RIoiCsKD, 0.0f);
  numBytes += cDelay_init(this, &cDelay_2xiwqzBb, 0.0f);
  numBytes += hTable_init(&hTable_bfZIbUE2, 256);
  numBytes += cTabhead_init(&cTabhead_KuKDDAKy, &hTable_bfZIbUE2);
  numBytes += cVar_init_s(&cVar_iBlM2YNM, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_LbHAWdME, 19.392f);
  numBytes += cDelay_init(this, &cDelay_CpwvU6KN, 0.0f);
  numBytes += cBinop_init(&cBinop_aEpMn5JC, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_7XSWL722, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_3xvi27y3, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_8KEEhMJ1, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_JUL9vMrs, 0.0f);
  numBytes += cDelay_init(this, &cDelay_RzRqe8NU, 0.0f);
  numBytes += hTable_init(&hTable_aZFFfkGW, 256);
  numBytes += cTabhead_init(&cTabhead_veAemnHH, &hTable_aZFFfkGW);
  numBytes += cVar_init_s(&cVar_QCLevWjb, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_h4KcIh6W, 16.364f);
  numBytes += cDelay_init(this, &cDelay_ZcYu1EdJ, 0.0f);
  numBytes += cBinop_init(&cBinop_SJNIBe5O, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_cnKVz9C0, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_aW6m2UZZ, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_xh42LTo3, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_C6MCOhE1, 0.0f);
  numBytes += cDelay_init(this, &cDelay_hOOeF0PL, 0.0f);
  numBytes += hTable_init(&hTable_vPDozOK1, 256);
  numBytes += cTabhead_init(&cTabhead_rGnPWbvR, &hTable_vPDozOK1);
  numBytes += cVar_init_s(&cVar_jbI9yj8g, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_9KR5KSd4, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_wajJqACn, 0.0f);
  numBytes += cBinop_init(&cBinop_KYxLqhHI, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_GfEfYOvP, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_Nb4R9Ux3, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Vw8WsQxj, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_FdPMOmen, 0.0f);
  numBytes += cDelay_init(this, &cDelay_eaJ4cG0Y, 0.0f);
  numBytes += hTable_init(&hTable_txUpzsPV, 256);
  numBytes += cTabhead_init(&cTabhead_1wfFsth5, &hTable_txUpzsPV);
  numBytes += cVar_init_s(&cVar_P7oOt6IS, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_tAVQTxnX, 7.645f);
  numBytes += cDelay_init(this, &cDelay_6DMPrPpa, 0.0f);
  numBytes += cBinop_init(&cBinop_QPh0vIJm, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_PxFxd5Tz, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_pWUKyF8S, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_IgX2paaP, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_0Br73mqd, 0.0f);
  numBytes += cVar_init_f(&cVar_BCpIrUv0, 0.0f);
  numBytes += cPack_init(&cPack_5PGVfP3j, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_Sosyff7K, 22050.0f);
  numBytes += cBinop_init(&cBinop_f5JM40rC, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_rlnKNXuQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_A4lRuYRx, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_mFtGvgxo, 22050.0f);
  numBytes += cBinop_init(&cBinop_cxZZMx5J, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_JIzMvRoq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vruzbMdq, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_j4QpksgS, 22050.0f);
  numBytes += cBinop_init(&cBinop_hBUEOzfB, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_qpdtmYPX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MwTAystm, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_x1nWPBEA, 0.0f);
  numBytes += cVar_init_f(&cVar_hSakqM93, 1000.0f);
  numBytes += cBinop_init(&cBinop_2AyaEYOj, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_o5OfGGrB, 0.0f);
  numBytes += cVar_init_f(&cVar_RrBeYUmS, 0.0f);
  numBytes += cIf_init(&cIf_hhgbF70R, false);
  numBytes += cDelay_init(this, &cDelay_ZSlQ9OCu, 0.0f);
  numBytes += cDelay_init(this, &cDelay_IPrnNLZb, 0.0f);
  numBytes += hTable_init(&hTable_JAMez6mH, 256);
  numBytes += cTabhead_init(&cTabhead_U0UHf1yz, &hTable_JAMez6mH);
  numBytes += cVar_init_s(&cVar_elqioPSN, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_M1C8TJbm, 150.0f);
  numBytes += cDelay_init(this, &cDelay_nf9MXItr, 0.0f);
  numBytes += cBinop_init(&cBinop_L1rGFrrx, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_ygznpXmp, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_yKe8bL0k, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_JkpeHpZw, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_kXBD1Iql, 0.0f);
  numBytes += cVar_init_f(&cVar_TtaVeKkP, 0.0f);
  numBytes += cVar_init_f(&cVar_T0YoAxYO, 0.0f);
  numBytes += cVar_init_f(&cVar_BdVYQilN, 0.0f);
  numBytes += cVar_init_f(&cVar_54ndX7JH, 0.0f);
  numBytes += cVar_init_f(&cVar_yTg8OlgU, 0.0f);
  numBytes += cIf_init(&cIf_SzQQ5bpu, false);
  numBytes += cVar_init_f(&cVar_MQew5eT6, 0.0f);
  numBytes += cIf_init(&cIf_AbU2pxTx, false);
  numBytes += cSlice_init(&cSlice_cg3iAZsb, 1, -1);
  numBytes += cSlice_init(&cSlice_lxAfixgD, 1, -1);
  numBytes += cVar_init_f(&cVar_TZaQ4lMH, 0.0f);
  numBytes += cIf_init(&cIf_vcOhUZPs, false);
  numBytes += cBinop_init(&cBinop_hwkBv5n6, 0.0f); // __neq
  numBytes += cIf_init(&cIf_QBoDI2NG, false);
  numBytes += cIf_init(&cIf_7DY1HdZE, false);
  numBytes += cIf_init(&cIf_LxqzgTxs, false);
  numBytes += cIf_init(&cIf_x5dnksIx, true);
  numBytes += cIf_init(&cIf_WuQs2qI7, false);
  numBytes += sVarf_init(&sVarf_Du99ZcVc, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_BSlSwIm3, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_XTMT3cTY, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_hudb3tQE, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_0gPy52HJ, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_Bb40zEgq, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_U4QKwSCH, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_rr5vawxG, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_ENm51JDy, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_V0V4NzNH, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_cuHHyBjo, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_JeM1FE3d, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_3eBKxwqB, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_1jAE3DCI);
  cPack_free(&cPack_BoFCiufk);
  hTable_free(&hTable_JZVqIjie);
  hTable_free(&hTable_J14ZW1WJ);
  hTable_free(&hTable_LI5YLypx);
  hTable_free(&hTable_CxkVjPhG);
  hTable_free(&hTable_8gOXB3xq);
  cPack_free(&cPack_L03sZepT);
  cPack_free(&cPack_PQFiP9kx);
  hTable_free(&hTable_SOnKytj4);
  hTable_free(&hTable_iwhjOLJz);
  hTable_free(&hTable_bfZIbUE2);
  hTable_free(&hTable_aZFFfkGW);
  hTable_free(&hTable_vPDozOK1);
  hTable_free(&hTable_txUpzsPV);
  cPack_free(&cPack_5PGVfP3j);
  hTable_free(&hTable_JAMez6mH);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_JZVqIjie; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_J14ZW1WJ; // del-1052-del1
    case 0xA2AC524D: return &hTable_LI5YLypx; // del-1052-del2
    case 0xE36A35B: return &hTable_CxkVjPhG; // del-1052-del3
    case 0x48CE0509: return &hTable_8gOXB3xq; // del-1052-del4
    case 0xE34D6E72: return &hTable_SOnKytj4; // del-1052-ref1
    case 0x6A1027AB: return &hTable_iwhjOLJz; // del-1052-ref2
    case 0xA37C6D49: return &hTable_bfZIbUE2; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_aZFFfkGW; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_vPDozOK1; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_txUpzsPV; // del-1052-ref5
    case 0xED65564F: return &hTable_JAMez6mH; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RWrJN7yj_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Np88CS64_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_y89s2KcE_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_W3bUhQDw_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_g9nB60eR_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hcR6sVxJ_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LptUNHrb_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UJYKIeBu_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3S76Dqtw_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3zQ4OCSA_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iZedKVwx_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UXF8HLKT_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rCTKJLa3_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_un3WBGgJ_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kOZMDCap_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PhB6hpe2_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yM8UVwgE_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vcYOh2sI_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lB4cQQoV_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dTLssDxs_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JrThWtRQ_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hIj3NGVN_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GG0nQnZM_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qzJf6JPu_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_8NNRIa7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_rBKep36M_sendMessage);
}

void Heavy_ChaffVerb::cVar_QUfu7EPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_XneGJasO_sendMessage);
}

void Heavy_ChaffVerb::cPack_1jAE3DCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_W0S3zo6T, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_A2gOZBfT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IwHxtQok, 0, m, &cVar_IwHxtQok_sendMessage);
}

void Heavy_ChaffVerb::cBinop_exzTWxYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_A2gOZBfT_sendMessage);
}

void Heavy_ChaffVerb::cVar_IwHxtQok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_uyCqeMWw_sendMessage);
}

void Heavy_ChaffVerb::cPack_BoFCiufk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_pt55X9SE, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_X61L4Xql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_kLMaVwDN_sendMessage);
}

void Heavy_ChaffVerb::cVar_fVKiztGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_XP3gf8Xc, 0, m);
}

void Heavy_ChaffVerb::cMsg_WDyGCps6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hBtVC1YN_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hBtVC1YN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_uBwgY87m_sendMessage);
}

void Heavy_ChaffVerb::cDelay_SGEStiVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SGEStiVU, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xbn03kxx, 0, m, &cDelay_xbn03kxx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SGEStiVU, 0, m, &cDelay_SGEStiVU_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_G7GNzQsX, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_xbn03kxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xbn03kxx, m);
  cMsg_CpOWnaY2_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_xvSpHPLk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_XtqZbJey_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_HIgk2fe9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_603mzska_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_JZVqIjie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1f5JXOkO_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SGEStiVU, 2, m, &cDelay_SGEStiVU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_txo6JOJI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_603mzska_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_JZVqIjie, 0, m, &hTable_JZVqIjie_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uBwgY87m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_HIgk2fe9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CpOWnaY2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_JZVqIjie, 0, m, &hTable_JZVqIjie_sendMessage);
}

void Heavy_ChaffVerb::cCast_txo6JOJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SGEStiVU, 0, m, &cDelay_SGEStiVU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1f5JXOkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_xbn03kxx, 2, m, &cDelay_xbn03kxx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XtqZbJey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_G7GNzQsX, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_54SvMGMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_c4ZFi1xD_sendMessage);
}

void Heavy_ChaffVerb::cSystem_c4ZFi1xD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2fGU6gTw_sendMessage);
}

void Heavy_ChaffVerb::cVar_q6kq3Ubp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NVMx3H8G_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_G8pthHmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_4k7hSCfQ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lyO5EoeL, m);
}

void Heavy_ChaffVerb::cBinop_2fGU6gTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_27eG82Sn, m);
}

void Heavy_ChaffVerb::cMsg_NVMx3H8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_G8pthHmJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4k7hSCfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_BU9Bd5lz, m);
}

void Heavy_ChaffVerb::cMsg_jHzRnEmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YWFVhKJ1_sendMessage);
}

void Heavy_ChaffVerb::cSystem_YWFVhKJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Dhf7tpHd_sendMessage);
}

void Heavy_ChaffVerb::cVar_0KUY8ZEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q5EFCw8E_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_gCnHxj6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_rniJcE7R_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wzhbASVN, m);
}

void Heavy_ChaffVerb::cBinop_Dhf7tpHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Uz0pXEA5, m);
}

void Heavy_ChaffVerb::cMsg_q5EFCw8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gCnHxj6p_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rniJcE7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vSvusw1r, m);
}

void Heavy_ChaffVerb::cBinop_Bt5A0mb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fVKiztGD, 0, m, &cVar_fVKiztGD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sNq7I5Nm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FtRYl4rc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SEfjl6L9_sendMessage);
}

void Heavy_ChaffVerb::cCast_SEfjl6L9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bt5A0mb7, HV_BINOP_DIVIDE, 0, m, &cBinop_Bt5A0mb7_sendMessage);
}

void Heavy_ChaffVerb::cCast_FtRYl4rc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bt5A0mb7, HV_BINOP_DIVIDE, 1, m, &cBinop_Bt5A0mb7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uyCqeMWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_E5H6yPG3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rBKep36M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_exzTWxYQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_E5H6yPG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bt5A0mb7, HV_BINOP_DIVIDE, 0, m, &cBinop_Bt5A0mb7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kLMaVwDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_BoFCiufk, 0, m, &cPack_BoFCiufk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XneGJasO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_sNq7I5Nm_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_1jAE3DCI, 0, m, &cPack_1jAE3DCI_sendMessage);
}

void Heavy_ChaffVerb::cUnop_ZKo2XtQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7DY1HdZE, 0, m, &cIf_7DY1HdZE_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_0EXbdyvH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ISVPd5rh_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oWzL8J2N_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QFRDVWci_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_ISVPd5rh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_niAFxcPo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_oWzL8J2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lL8JFIiY_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_QFRDVWci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HuVE1Axr_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_3fqi2kCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_G8zcBb43_sendMessage);
}

void Heavy_ChaffVerb::cBinop_G8zcBb43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_un2dSYgb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_cEkF4vBC_sendMessage);
}

void Heavy_ChaffVerb::cVar_wxbRyfFo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_7z7pOrJN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gXDA5xkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_m9t7RWei_sendMessage);
}

void Heavy_ChaffVerb::cSystem_m9t7RWei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mpKhiEz8, HV_BINOP_DIVIDE, 1, m, &cBinop_mpKhiEz8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_un2dSYgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EPBAxlMf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EPBAxlMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_U3gUg70q, m);
}

void Heavy_ChaffVerb::cMsg_avD4cbEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Apwj17rY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Apwj17rY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_3fqi2kCS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cEkF4vBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ViOOKQ9O, m);
}

void Heavy_ChaffVerb::cBinop_7z7pOrJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_0r5PDND8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0r5PDND8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mpKhiEz8, HV_BINOP_DIVIDE, 0, m, &cBinop_mpKhiEz8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mpKhiEz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_avD4cbEi_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_NSwzd9u9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_upzpxO1p, 0, m, &cSlice_upzpxO1p_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_AuaYEc1M, 0, m, &cRandom_AuaYEc1M_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_91jILYT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_z6x2gNGK_sendMessage);
}

void Heavy_ChaffVerb::cUnop_z6x2gNGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_phssu0qR_sendMessage);
}

void Heavy_ChaffVerb::cRandom_AuaYEc1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_91jILYT4_sendMessage);
}

void Heavy_ChaffVerb::cSlice_upzpxO1p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_AuaYEc1M, 1, m, &cRandom_AuaYEc1M_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_ZzJJruCe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_XHxOoCzk_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_XHxOoCzk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AtkJCIYl_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_76Xj2iln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_76Xj2iln, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_76Xj2iln, 0, m, &cDelay_76Xj2iln_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_o5OfGGrB, 0, m, &cVar_o5OfGGrB_sendMessage);
}

void Heavy_ChaffVerb::cCast_AtkJCIYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XHxOoCzk_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_76Xj2iln, 0, m, &cDelay_76Xj2iln_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_o5OfGGrB, 0, m, &cVar_o5OfGGrB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CdLjn5lv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Xy8ya2tR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Xy8ya2tR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_tLaunBHK_sendMessage);
}

void Heavy_ChaffVerb::cVar_3lokLHSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hThsXw0k, HV_BINOP_MULTIPLY, 0, m, &cBinop_hThsXw0k_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XHxOoCzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_76Xj2iln, 0, m, &cDelay_76Xj2iln_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uWQjPZ1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_76Xj2iln, 2, m, &cDelay_76Xj2iln_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tLaunBHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hThsXw0k, HV_BINOP_MULTIPLY, 1, m, &cBinop_hThsXw0k_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hThsXw0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_uWQjPZ1j_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_vrtdTNeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_47YUDVPL, HV_BINOP_SUBTRACT, 0, m, &cBinop_47YUDVPL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_srckXUuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9NnXeF9p_sendMessage);
}

void Heavy_ChaffVerb::cSystem_9NnXeF9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_vYv0ApE8_sendMessage);
}

void Heavy_ChaffVerb::cVar_j51w71ej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iekFGMBF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_7ccO1kzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7ccO1kzF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1HM3i1EO, 0, m, &cDelay_1HM3i1EO_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_QSCHG0IJ, 0, m, &sTabread_QSCHG0IJ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_1HM3i1EO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1HM3i1EO, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_QSCHG0IJ, 0, m, &sTabread_QSCHG0IJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1HM3i1EO, 0, m, &cDelay_1HM3i1EO_sendMessage);
}

void Heavy_ChaffVerb::sTabread_QSCHG0IJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_V9koebQb, HV_BINOP_SUBTRACT, 0, m, &cBinop_V9koebQb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_uAHzBCZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FU4oXBfB, HV_BINOP_MAX, 0, m, &cBinop_FU4oXBfB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vYv0ApE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uAHzBCZj, HV_BINOP_MULTIPLY, 0, m, &cBinop_uAHzBCZj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_47YUDVPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UBoki3rG_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_QSCHG0IJ, 0, m, &sTabread_QSCHG0IJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0n2vnpT5_sendMessage);
}

void Heavy_ChaffVerb::cSystem_GZMCGtHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V9koebQb, HV_BINOP_SUBTRACT, 1, m, &cBinop_V9koebQb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1HM3i1EO, 2, m, &cDelay_1HM3i1EO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iekFGMBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GZMCGtHc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UBoki3rG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7ccO1kzF, 0, m, &cDelay_7ccO1kzF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1HM3i1EO, 0, m, &cDelay_1HM3i1EO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_En6XCdb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_FU4oXBfB, HV_BINOP_MAX, 1, m, &cBinop_FU4oXBfB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FU4oXBfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_47YUDVPL, HV_BINOP_SUBTRACT, 1, m, &cBinop_47YUDVPL_sendMessage);
}

void Heavy_ChaffVerb::cCast_0n2vnpT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7ccO1kzF, 0, m, &cDelay_7ccO1kzF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YkJlTFjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7ccO1kzF, 2, m, &cDelay_7ccO1kzF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_V9koebQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_YkJlTFjL_sendMessage);
}

void Heavy_ChaffVerb::cCast_RS8ODQkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j51w71ej, 0, m, &cVar_j51w71ej_sendMessage);
  cMsg_srckXUuK_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vrtdTNeb, 0, m, &cTabhead_vrtdTNeb_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_UBAUBOvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LQeAk7KF, HV_BINOP_SUBTRACT, 0, m, &cBinop_LQeAk7KF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UsMx4d56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HmpcaSDD_sendMessage);
}

void Heavy_ChaffVerb::cSystem_HmpcaSDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_UBvK8YFZ_sendMessage);
}

void Heavy_ChaffVerb::cVar_TApWqnzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eWx60uqF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_ejMao2K3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ejMao2K3, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bi1YY0KK, 0, m, &cDelay_bi1YY0KK_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_AooxjNXh, 0, m, &sTabread_AooxjNXh_sendMessage);
}

void Heavy_ChaffVerb::cDelay_bi1YY0KK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bi1YY0KK, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_AooxjNXh, 0, m, &sTabread_AooxjNXh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bi1YY0KK, 0, m, &cDelay_bi1YY0KK_sendMessage);
}

void Heavy_ChaffVerb::sTabread_AooxjNXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_qZJRNmZH, HV_BINOP_SUBTRACT, 0, m, &cBinop_qZJRNmZH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_KRehpgxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wfeKkFrt, HV_BINOP_MAX, 0, m, &cBinop_wfeKkFrt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UBvK8YFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KRehpgxi, HV_BINOP_MULTIPLY, 0, m, &cBinop_KRehpgxi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LQeAk7KF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q7VctYDq_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_AooxjNXh, 0, m, &sTabread_AooxjNXh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xOuT3Soj_sendMessage);
}

void Heavy_ChaffVerb::cSystem_d3bswzs0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qZJRNmZH, HV_BINOP_SUBTRACT, 1, m, &cBinop_qZJRNmZH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bi1YY0KK, 2, m, &cDelay_bi1YY0KK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_eWx60uqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_d3bswzs0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_q7VctYDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ejMao2K3, 0, m, &cDelay_ejMao2K3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bi1YY0KK, 0, m, &cDelay_bi1YY0KK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jLra77Nw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_wfeKkFrt, HV_BINOP_MAX, 1, m, &cBinop_wfeKkFrt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wfeKkFrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LQeAk7KF, HV_BINOP_SUBTRACT, 1, m, &cBinop_LQeAk7KF_sendMessage);
}

void Heavy_ChaffVerb::cCast_xOuT3Soj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ejMao2K3, 0, m, &cDelay_ejMao2K3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rPi0Wngs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ejMao2K3, 2, m, &cDelay_ejMao2K3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qZJRNmZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rPi0Wngs_sendMessage);
}

void Heavy_ChaffVerb::cCast_nRTvxAbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TApWqnzX, 0, m, &cVar_TApWqnzX_sendMessage);
  cMsg_UsMx4d56_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_UBAUBOvl, 0, m, &cTabhead_UBAUBOvl_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_mvgOoFRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j7eEbx4f, HV_BINOP_SUBTRACT, 0, m, &cBinop_j7eEbx4f_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GETqy3XJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Xq7smW8A_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Xq7smW8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yL9mxAoK_sendMessage);
}

void Heavy_ChaffVerb::cVar_o2Go43DW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VH91JAg2_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_c7D9aVPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_c7D9aVPT, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h8FaH1rY, 0, m, &cDelay_h8FaH1rY_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_3sWiG9ce, 0, m, &sTabread_3sWiG9ce_sendMessage);
}

void Heavy_ChaffVerb::cDelay_h8FaH1rY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_h8FaH1rY, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_3sWiG9ce, 0, m, &sTabread_3sWiG9ce_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h8FaH1rY, 0, m, &cDelay_h8FaH1rY_sendMessage);
}

void Heavy_ChaffVerb::sTabread_3sWiG9ce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_864jUkBr, HV_BINOP_SUBTRACT, 0, m, &cBinop_864jUkBr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_xdFLddNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z5skfGXF, HV_BINOP_MAX, 0, m, &cBinop_z5skfGXF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yL9mxAoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xdFLddNR, HV_BINOP_MULTIPLY, 0, m, &cBinop_xdFLddNR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_j7eEbx4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zkI8W812_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_3sWiG9ce, 0, m, &sTabread_3sWiG9ce_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tkj5DesW_sendMessage);
}

void Heavy_ChaffVerb::cSystem_LBAgLHsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_864jUkBr, HV_BINOP_SUBTRACT, 1, m, &cBinop_864jUkBr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h8FaH1rY, 2, m, &cDelay_h8FaH1rY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VH91JAg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LBAgLHsO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zkI8W812_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_c7D9aVPT, 0, m, &cDelay_c7D9aVPT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h8FaH1rY, 0, m, &cDelay_h8FaH1rY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_laqWFmX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_z5skfGXF, HV_BINOP_MAX, 1, m, &cBinop_z5skfGXF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_z5skfGXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j7eEbx4f, HV_BINOP_SUBTRACT, 1, m, &cBinop_j7eEbx4f_sendMessage);
}

void Heavy_ChaffVerb::cCast_tkj5DesW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_c7D9aVPT, 0, m, &cDelay_c7D9aVPT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_o1r2bLPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_c7D9aVPT, 2, m, &cDelay_c7D9aVPT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_864jUkBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_o1r2bLPK_sendMessage);
}

void Heavy_ChaffVerb::cCast_MoeAtNMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o2Go43DW, 0, m, &cVar_o2Go43DW_sendMessage);
  cMsg_GETqy3XJ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_mvgOoFRf, 0, m, &cTabhead_mvgOoFRf_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_MebRHg9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nk5fk44T, HV_BINOP_SUBTRACT, 0, m, &cBinop_Nk5fk44T_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0MbOij7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6nZJ4UYk_sendMessage);
}

void Heavy_ChaffVerb::cSystem_6nZJ4UYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_SeGqnnO8_sendMessage);
}

void Heavy_ChaffVerb::cVar_MDpLXs8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K3d4ETVZ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_ZPNQQZqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZPNQQZqj, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FLEg3Npi, 0, m, &cDelay_FLEg3Npi_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_LGbwZp1r, 0, m, &sTabread_LGbwZp1r_sendMessage);
}

void Heavy_ChaffVerb::cDelay_FLEg3Npi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FLEg3Npi, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_LGbwZp1r, 0, m, &sTabread_LGbwZp1r_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FLEg3Npi, 0, m, &cDelay_FLEg3Npi_sendMessage);
}

void Heavy_ChaffVerb::sTabread_LGbwZp1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Bk6mwB1s, HV_BINOP_SUBTRACT, 0, m, &cBinop_Bk6mwB1s_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_2tAEBcWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9FoCUWdl, HV_BINOP_MAX, 0, m, &cBinop_9FoCUWdl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SeGqnnO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2tAEBcWl, HV_BINOP_MULTIPLY, 0, m, &cBinop_2tAEBcWl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Nk5fk44T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5TI3d7lG_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_LGbwZp1r, 0, m, &sTabread_LGbwZp1r_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xyoN98pQ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Qvkg0fYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bk6mwB1s, HV_BINOP_SUBTRACT, 1, m, &cBinop_Bk6mwB1s_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FLEg3Npi, 2, m, &cDelay_FLEg3Npi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_K3d4ETVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Qvkg0fYL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5TI3d7lG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZPNQQZqj, 0, m, &cDelay_ZPNQQZqj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FLEg3Npi, 0, m, &cDelay_FLEg3Npi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_F4E5Pk94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_9FoCUWdl, HV_BINOP_MAX, 1, m, &cBinop_9FoCUWdl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9FoCUWdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nk5fk44T, HV_BINOP_SUBTRACT, 1, m, &cBinop_Nk5fk44T_sendMessage);
}

void Heavy_ChaffVerb::cCast_xyoN98pQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZPNQQZqj, 0, m, &cDelay_ZPNQQZqj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Inw8F8Dg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZPNQQZqj, 2, m, &cDelay_ZPNQQZqj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Bk6mwB1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Inw8F8Dg_sendMessage);
}

void Heavy_ChaffVerb::cCast_ameKGybK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MDpLXs8q, 0, m, &cVar_MDpLXs8q_sendMessage);
  cMsg_0MbOij7d_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_MebRHg9W, 0, m, &cTabhead_MebRHg9W_sendMessage);
}

void Heavy_ChaffVerb::cMsg_h5ZfUkyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0z1QmoVZ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_0z1QmoVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ukNBIjrS_sendMessage);
}

void Heavy_ChaffVerb::cDelay_AtRccqw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AtRccqw0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OEybK1Rs, 0, m, &cDelay_OEybK1Rs_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AtRccqw0, 0, m, &cDelay_AtRccqw0_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_F3uA3heL, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_OEybK1Rs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OEybK1Rs, m);
  cMsg_pUB0qEgc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_fvUeDhhF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_wBtZDcez_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_FMgXuaw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4GXy3sYC_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_J14ZW1WJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sLSdXp9p_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AtRccqw0, 2, m, &cDelay_AtRccqw0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mnLzM7Cc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4GXy3sYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_J14ZW1WJ, 0, m, &hTable_J14ZW1WJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ukNBIjrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_FMgXuaw3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pUB0qEgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_J14ZW1WJ, 0, m, &hTable_J14ZW1WJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_mnLzM7Cc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AtRccqw0, 0, m, &cDelay_AtRccqw0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sLSdXp9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_OEybK1Rs, 2, m, &cDelay_OEybK1Rs_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wBtZDcez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_F3uA3heL, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_3BtDYzQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DdGiUNQu_sendMessage);
}

void Heavy_ChaffVerb::cSystem_DdGiUNQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_tp8dAKnx_sendMessage);
}

void Heavy_ChaffVerb::cDelay_YJ6Cn1mo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YJ6Cn1mo, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_I5DXKQcd, 0, m, &cDelay_I5DXKQcd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YJ6Cn1mo, 0, m, &cDelay_YJ6Cn1mo_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_VvCDIds8, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_I5DXKQcd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_I5DXKQcd, m);
  cMsg_CzRppoT1_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_f2ZJx0K6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_p8B1pUrO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_2ghCrVJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FnD4rgVb_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_LI5YLypx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GuA335rA_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YJ6Cn1mo, 2, m, &cDelay_YJ6Cn1mo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yqiNuYYi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FnD4rgVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_LI5YLypx, 0, m, &hTable_LI5YLypx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tp8dAKnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_2ghCrVJ6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CzRppoT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_LI5YLypx, 0, m, &hTable_LI5YLypx_sendMessage);
}

void Heavy_ChaffVerb::cCast_yqiNuYYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YJ6Cn1mo, 0, m, &cDelay_YJ6Cn1mo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GuA335rA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_I5DXKQcd, 2, m, &cDelay_I5DXKQcd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_p8B1pUrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_VvCDIds8, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_dzkZizOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_COgMuM1P_sendMessage);
}

void Heavy_ChaffVerb::cSystem_COgMuM1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_z7Nqeqhg_sendMessage);
}

void Heavy_ChaffVerb::cDelay_nmVtwXef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nmVtwXef, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VYDrfIVK, 0, m, &cDelay_VYDrfIVK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nmVtwXef, 0, m, &cDelay_nmVtwXef_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_qwpoaRyi, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_VYDrfIVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VYDrfIVK, m);
  cMsg_xOOufnOJ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_qJ7ltNSt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_jU6hcS7t_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_829e4Cxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SdpojGFW_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_CxkVjPhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Op6zmxUf_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nmVtwXef, 2, m, &cDelay_nmVtwXef_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gMT5ylhp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SdpojGFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_CxkVjPhG, 0, m, &hTable_CxkVjPhG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_z7Nqeqhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_829e4Cxe_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xOOufnOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_CxkVjPhG, 0, m, &hTable_CxkVjPhG_sendMessage);
}

void Heavy_ChaffVerb::cCast_gMT5ylhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nmVtwXef, 0, m, &cDelay_nmVtwXef_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Op6zmxUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_VYDrfIVK, 2, m, &cDelay_VYDrfIVK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jU6hcS7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_qwpoaRyi, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_1q5iAMK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JDl72FGE_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JDl72FGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gZOVAsUo_sendMessage);
}

void Heavy_ChaffVerb::cDelay_4FlYFCJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4FlYFCJy, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_klEDt1lK, 0, m, &cDelay_klEDt1lK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4FlYFCJy, 0, m, &cDelay_4FlYFCJy_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4C14w19W, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_klEDt1lK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_klEDt1lK, m);
  cMsg_tZIrO3Fq_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_DhnpOgKq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_3SEljIKK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_nxZMyrob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u9WdO9Qo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_8gOXB3xq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zfGU2lmI_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4FlYFCJy, 2, m, &cDelay_4FlYFCJy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2NL7SNMC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_u9WdO9Qo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_8gOXB3xq, 0, m, &hTable_8gOXB3xq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gZOVAsUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_nxZMyrob_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tZIrO3Fq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_8gOXB3xq, 0, m, &hTable_8gOXB3xq_sendMessage);
}

void Heavy_ChaffVerb::cCast_2NL7SNMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4FlYFCJy, 0, m, &cDelay_4FlYFCJy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zfGU2lmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_klEDt1lK, 2, m, &cDelay_klEDt1lK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3SEljIKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4C14w19W, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_L03sZepT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_LgBv0MbP, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_PQFiP9kx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_F4Qdw6P6, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_WRwn5aCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fQIZxBAO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fQIZxBAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_Zmraf37m_sendMessage);
}

void Heavy_ChaffVerb::cVar_l18xolK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nQTFRM1s, HV_BINOP_MULTIPLY, 0, m, &cBinop_nQTFRM1s_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5tUBN5BQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Q5NJoIXr_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Q5NJoIXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nGlfQVYA_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_nQTFRM1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_npwmuVmb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7KffNp2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nQTFRM1s, HV_BINOP_MULTIPLY, 1, m, &cBinop_nQTFRM1s_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nGlfQVYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7KffNp2E_sendMessage);
}

void Heavy_ChaffVerb::cBinop_npwmuVmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_KPJjALpw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KPJjALpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_lDgPhFkm_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6KEKAhKT, m);
}

void Heavy_ChaffVerb::cBinop_lDgPhFkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5YmX3rzA, m);
}

void Heavy_ChaffVerb::cVar_yv9hOr3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_gB6n6uLL_sendMessage);
}

void Heavy_ChaffVerb::cVar_OqmMB7QP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_WRwn5aCX_sendMessage);
}

void Heavy_ChaffVerb::cVar_NIqBN0fN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_mGt2koja_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_O2He96s7, 0, m, &cIf_O2He96s7_sendMessage);
}

void Heavy_ChaffVerb::cVar_SE81RVtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_8H9Pj0Vm_sendMessage);
}

void Heavy_ChaffVerb::cIf_O2He96s7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_oep2mXqM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_0Br73mqd, 0, m, &cVar_0Br73mqd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_mGt2koja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O2He96s7, 1, m, &cIf_O2He96s7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8H9Pj0Vm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ZIM32DDV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZIM32DDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BCpIrUv0, 0, m, &cVar_BCpIrUv0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Otal4Rm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8PCiIGTc_sendMessage);
}

void Heavy_ChaffVerb::cSystem_8PCiIGTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_bKk0j5zi_sendMessage);
}

void Heavy_ChaffVerb::cDelay_clkx5YQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_clkx5YQB, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZUBHcdlZ, 0, m, &cDelay_ZUBHcdlZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_clkx5YQB, 0, m, &cDelay_clkx5YQB_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4d2bpFph, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_ZUBHcdlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZUBHcdlZ, m);
  cMsg_DP9edkKn_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_HqxfuSUf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_LvzQaRPi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_stelZnfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5rpRIrCT_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_SOnKytj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zPm56Ibu_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_clkx5YQB, 2, m, &cDelay_clkx5YQB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6xeWq5pG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5rpRIrCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_SOnKytj4, 0, m, &hTable_SOnKytj4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bKk0j5zi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_stelZnfB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DP9edkKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_SOnKytj4, 0, m, &hTable_SOnKytj4_sendMessage);
}

void Heavy_ChaffVerb::cCast_6xeWq5pG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_clkx5YQB, 0, m, &cDelay_clkx5YQB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zPm56Ibu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZUBHcdlZ, 2, m, &cDelay_ZUBHcdlZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LvzQaRPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4d2bpFph, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_1gMbtVIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cAEYCNPR, HV_BINOP_SUBTRACT, 0, m, &cBinop_cAEYCNPR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_F30VkCpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_s2yBO4nD_sendMessage);
}

void Heavy_ChaffVerb::cSystem_s2yBO4nD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_pH0W8QKE_sendMessage);
}

void Heavy_ChaffVerb::cVar_voeK0Cvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lEOmiRZG_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_OplJ2uFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OplJ2uFu, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_s9bvGrqQ, 0, m, &cDelay_s9bvGrqQ_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_wTihnYjl, 0, m, &sTabread_wTihnYjl_sendMessage);
}

void Heavy_ChaffVerb::cDelay_s9bvGrqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_s9bvGrqQ, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_wTihnYjl, 0, m, &sTabread_wTihnYjl_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_s9bvGrqQ, 0, m, &cDelay_s9bvGrqQ_sendMessage);
}

void Heavy_ChaffVerb::sTabread_wTihnYjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_qSiqonNN, HV_BINOP_SUBTRACT, 0, m, &cBinop_qSiqonNN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_rNLmOMtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kfeORq0g, HV_BINOP_MAX, 0, m, &cBinop_kfeORq0g_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pH0W8QKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rNLmOMtV, HV_BINOP_MULTIPLY, 0, m, &cBinop_rNLmOMtV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cAEYCNPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WsEgbcUx_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_wTihnYjl, 0, m, &sTabread_wTihnYjl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dDPBuqA8_sendMessage);
}

void Heavy_ChaffVerb::cSystem_LqSnI6A1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qSiqonNN, HV_BINOP_SUBTRACT, 1, m, &cBinop_qSiqonNN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_s9bvGrqQ, 2, m, &cDelay_s9bvGrqQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lEOmiRZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LqSnI6A1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WsEgbcUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OplJ2uFu, 0, m, &cDelay_OplJ2uFu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_s9bvGrqQ, 0, m, &cDelay_s9bvGrqQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_V9SZxp8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_kfeORq0g, HV_BINOP_MAX, 1, m, &cBinop_kfeORq0g_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kfeORq0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cAEYCNPR, HV_BINOP_SUBTRACT, 1, m, &cBinop_cAEYCNPR_sendMessage);
}

void Heavy_ChaffVerb::cCast_dDPBuqA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OplJ2uFu, 0, m, &cDelay_OplJ2uFu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_y2CjZXMT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OplJ2uFu, 2, m, &cDelay_OplJ2uFu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qSiqonNN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_y2CjZXMT_sendMessage);
}

void Heavy_ChaffVerb::cCast_CM4Y2uds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_voeK0Cvo, 0, m, &cVar_voeK0Cvo_sendMessage);
  cMsg_F30VkCpd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_1gMbtVIf, 0, m, &cTabhead_1gMbtVIf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rrqvLkjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sOY0UMp3_sendMessage);
}

void Heavy_ChaffVerb::cSystem_sOY0UMp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cx1RYuJZ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Wi2qnehE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Wi2qnehE, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8vL8PQ4v, 0, m, &cDelay_8vL8PQ4v_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Wi2qnehE, 0, m, &cDelay_Wi2qnehE_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_xADlMFnm, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_8vL8PQ4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8vL8PQ4v, m);
  cMsg_A3RUd5eu_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_yX2xNQkK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_2Qi69lhR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_4CMEPGf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Re1HtqoA_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_iwhjOLJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xR0cDi5u_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Wi2qnehE, 2, m, &cDelay_Wi2qnehE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zbNdt9jA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Re1HtqoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_iwhjOLJz, 0, m, &hTable_iwhjOLJz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cx1RYuJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_4CMEPGf8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_A3RUd5eu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_iwhjOLJz, 0, m, &hTable_iwhjOLJz_sendMessage);
}

void Heavy_ChaffVerb::cCast_zbNdt9jA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Wi2qnehE, 0, m, &cDelay_Wi2qnehE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xR0cDi5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_8vL8PQ4v, 2, m, &cDelay_8vL8PQ4v_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2Qi69lhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_xADlMFnm, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_2VtX2nvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1OJv3Nw0, HV_BINOP_SUBTRACT, 0, m, &cBinop_1OJv3Nw0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8YbGCUlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zM6vqNah_sendMessage);
}

void Heavy_ChaffVerb::cSystem_zM6vqNah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qLRWy8iA_sendMessage);
}

void Heavy_ChaffVerb::cVar_hNop4w4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L5VGwijs_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_KTYdMnby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KTYdMnby, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DCEXeQKq, 0, m, &cDelay_DCEXeQKq_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qE08cZ0T, 0, m, &sTabread_qE08cZ0T_sendMessage);
}

void Heavy_ChaffVerb::cDelay_DCEXeQKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DCEXeQKq, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qE08cZ0T, 0, m, &sTabread_qE08cZ0T_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DCEXeQKq, 0, m, &cDelay_DCEXeQKq_sendMessage);
}

void Heavy_ChaffVerb::sTabread_qE08cZ0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_NolNXImP, HV_BINOP_SUBTRACT, 0, m, &cBinop_NolNXImP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_5XoU9BKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i4SpdSmp, HV_BINOP_MAX, 0, m, &cBinop_i4SpdSmp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qLRWy8iA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5XoU9BKQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_5XoU9BKQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1OJv3Nw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xJFvzWjq_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qE08cZ0T, 0, m, &sTabread_qE08cZ0T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4ECF7Lk_sendMessage);
}

void Heavy_ChaffVerb::cSystem_AKXgCfC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NolNXImP, HV_BINOP_SUBTRACT, 1, m, &cBinop_NolNXImP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DCEXeQKq, 2, m, &cDelay_DCEXeQKq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_L5VGwijs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AKXgCfC9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xJFvzWjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KTYdMnby, 0, m, &cDelay_KTYdMnby_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DCEXeQKq, 0, m, &cDelay_DCEXeQKq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AfTfWCFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_i4SpdSmp, HV_BINOP_MAX, 1, m, &cBinop_i4SpdSmp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_i4SpdSmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1OJv3Nw0, HV_BINOP_SUBTRACT, 1, m, &cBinop_1OJv3Nw0_sendMessage);
}

void Heavy_ChaffVerb::cCast_R4ECF7Lk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KTYdMnby, 0, m, &cDelay_KTYdMnby_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xcW4csNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KTYdMnby, 2, m, &cDelay_KTYdMnby_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NolNXImP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xcW4csNj_sendMessage);
}

void Heavy_ChaffVerb::cCast_K3CDsduV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hNop4w4J, 0, m, &cVar_hNop4w4J_sendMessage);
  cMsg_8YbGCUlP_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_2VtX2nvk, 0, m, &cTabhead_2VtX2nvk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_p5kKzdGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_szT3G6yP_sendMessage);
}

void Heavy_ChaffVerb::cSystem_szT3G6yP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yMCEv1VJ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_RIoiCsKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RIoiCsKD, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2xiwqzBb, 0, m, &cDelay_2xiwqzBb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RIoiCsKD, 0, m, &cDelay_RIoiCsKD_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_H1ADYMjs, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_2xiwqzBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2xiwqzBb, m);
  cMsg_yFLUGUR1_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_MelOFGZf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_A5Gdkem4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_IKhOwbUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZWfoHn1s_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_bfZIbUE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2buiJBga_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RIoiCsKD, 2, m, &cDelay_RIoiCsKD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ps7QSi2S_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZWfoHn1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_bfZIbUE2, 0, m, &hTable_bfZIbUE2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yMCEv1VJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_IKhOwbUn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yFLUGUR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_bfZIbUE2, 0, m, &hTable_bfZIbUE2_sendMessage);
}

void Heavy_ChaffVerb::cCast_ps7QSi2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RIoiCsKD, 0, m, &cDelay_RIoiCsKD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2buiJBga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_2xiwqzBb, 2, m, &cDelay_2xiwqzBb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_A5Gdkem4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_H1ADYMjs, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_KuKDDAKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7XSWL722, HV_BINOP_SUBTRACT, 0, m, &cBinop_7XSWL722_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kBF5yQkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_axPRnUMZ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_axPRnUMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_YsWkTQoP_sendMessage);
}

void Heavy_ChaffVerb::cVar_iBlM2YNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_13VRMCoE_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_LbHAWdME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LbHAWdME, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CpwvU6KN, 0, m, &cDelay_CpwvU6KN_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_hafWPAXo, 0, m, &sTabread_hafWPAXo_sendMessage);
}

void Heavy_ChaffVerb::cDelay_CpwvU6KN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CpwvU6KN, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_hafWPAXo, 0, m, &sTabread_hafWPAXo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CpwvU6KN, 0, m, &cDelay_CpwvU6KN_sendMessage);
}

void Heavy_ChaffVerb::sTabread_hafWPAXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_8KEEhMJ1, HV_BINOP_SUBTRACT, 0, m, &cBinop_8KEEhMJ1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_aEpMn5JC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3xvi27y3, HV_BINOP_MAX, 0, m, &cBinop_3xvi27y3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YsWkTQoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aEpMn5JC, HV_BINOP_MULTIPLY, 0, m, &cBinop_aEpMn5JC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7XSWL722_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RorDRZuo_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_hafWPAXo, 0, m, &sTabread_hafWPAXo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iZFFWzBQ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_xMWwFzhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8KEEhMJ1, HV_BINOP_SUBTRACT, 1, m, &cBinop_8KEEhMJ1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CpwvU6KN, 2, m, &cDelay_CpwvU6KN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_13VRMCoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xMWwFzhl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RorDRZuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_LbHAWdME, 0, m, &cDelay_LbHAWdME_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CpwvU6KN, 0, m, &cDelay_CpwvU6KN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bNCQmAZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_3xvi27y3, HV_BINOP_MAX, 1, m, &cBinop_3xvi27y3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3xvi27y3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7XSWL722, HV_BINOP_SUBTRACT, 1, m, &cBinop_7XSWL722_sendMessage);
}

void Heavy_ChaffVerb::cCast_iZFFWzBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LbHAWdME, 0, m, &cDelay_LbHAWdME_sendMessage);
}

void Heavy_ChaffVerb::cBinop_h2Ho9R6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LbHAWdME, 2, m, &cDelay_LbHAWdME_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8KEEhMJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_h2Ho9R6p_sendMessage);
}

void Heavy_ChaffVerb::cCast_I8z6SLTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iBlM2YNM, 0, m, &cVar_iBlM2YNM_sendMessage);
  cMsg_kBF5yQkO_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_KuKDDAKy, 0, m, &cTabhead_KuKDDAKy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8DS3aw8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_t0H66Mbe_sendMessage);
}

void Heavy_ChaffVerb::cSystem_t0H66Mbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9w2rNrSm_sendMessage);
}

void Heavy_ChaffVerb::cDelay_JUL9vMrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JUL9vMrs, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RzRqe8NU, 0, m, &cDelay_RzRqe8NU_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JUL9vMrs, 0, m, &cDelay_JUL9vMrs_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_3Dra1G18, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_RzRqe8NU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RzRqe8NU, m);
  cMsg_sVfqzkyD_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_P5MZlRF8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_GQVTb9gc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_UClYYb9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oYQFKZEp_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_aZFFfkGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mV91JZ9F_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JUL9vMrs, 2, m, &cDelay_JUL9vMrs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PUOXQzEP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_oYQFKZEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_aZFFfkGW, 0, m, &hTable_aZFFfkGW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9w2rNrSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_UClYYb9p_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sVfqzkyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_aZFFfkGW, 0, m, &hTable_aZFFfkGW_sendMessage);
}

void Heavy_ChaffVerb::cCast_PUOXQzEP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JUL9vMrs, 0, m, &cDelay_JUL9vMrs_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mV91JZ9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_RzRqe8NU, 2, m, &cDelay_RzRqe8NU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GQVTb9gc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_3Dra1G18, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_veAemnHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cnKVz9C0, HV_BINOP_SUBTRACT, 0, m, &cBinop_cnKVz9C0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LWjZxpYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_B8h8HFPF_sendMessage);
}

void Heavy_ChaffVerb::cSystem_B8h8HFPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_QYXN3E0r_sendMessage);
}

void Heavy_ChaffVerb::cVar_QCLevWjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5PZGeM1O_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_h4KcIh6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_h4KcIh6W, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZcYu1EdJ, 0, m, &cDelay_ZcYu1EdJ_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_4IVa2Ccu, 0, m, &sTabread_4IVa2Ccu_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ZcYu1EdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZcYu1EdJ, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_4IVa2Ccu, 0, m, &sTabread_4IVa2Ccu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZcYu1EdJ, 0, m, &cDelay_ZcYu1EdJ_sendMessage);
}

void Heavy_ChaffVerb::sTabread_4IVa2Ccu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_xh42LTo3, HV_BINOP_SUBTRACT, 0, m, &cBinop_xh42LTo3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_SJNIBe5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aW6m2UZZ, HV_BINOP_MAX, 0, m, &cBinop_aW6m2UZZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QYXN3E0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SJNIBe5O, HV_BINOP_MULTIPLY, 0, m, &cBinop_SJNIBe5O_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cnKVz9C0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fAWeyVY5_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_4IVa2Ccu, 0, m, &sTabread_4IVa2Ccu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WIKs3k0N_sendMessage);
}

void Heavy_ChaffVerb::cSystem_MuSqpD9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xh42LTo3, HV_BINOP_SUBTRACT, 1, m, &cBinop_xh42LTo3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZcYu1EdJ, 2, m, &cDelay_ZcYu1EdJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5PZGeM1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MuSqpD9i_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fAWeyVY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_h4KcIh6W, 0, m, &cDelay_h4KcIh6W_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZcYu1EdJ, 0, m, &cDelay_ZcYu1EdJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hNEqMpan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_aW6m2UZZ, HV_BINOP_MAX, 1, m, &cBinop_aW6m2UZZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aW6m2UZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cnKVz9C0, HV_BINOP_SUBTRACT, 1, m, &cBinop_cnKVz9C0_sendMessage);
}

void Heavy_ChaffVerb::cCast_WIKs3k0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_h4KcIh6W, 0, m, &cDelay_h4KcIh6W_sendMessage);
}

void Heavy_ChaffVerb::cBinop_C1yIgzfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_h4KcIh6W, 2, m, &cDelay_h4KcIh6W_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xh42LTo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_C1yIgzfA_sendMessage);
}

void Heavy_ChaffVerb::cCast_y6rpm4bq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QCLevWjb, 0, m, &cVar_QCLevWjb_sendMessage);
  cMsg_LWjZxpYR_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_veAemnHH, 0, m, &cTabhead_veAemnHH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Cdyjl7D8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JFHJjIlv_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JFHJjIlv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_oShllf7X_sendMessage);
}

void Heavy_ChaffVerb::cDelay_C6MCOhE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_C6MCOhE1, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hOOeF0PL, 0, m, &cDelay_hOOeF0PL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C6MCOhE1, 0, m, &cDelay_C6MCOhE1_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_DDd7aiF4, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_hOOeF0PL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hOOeF0PL, m);
  cMsg_83WOeBlz_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_WuPXm2jV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_7qE1Z631_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_ArPdA94j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NOitcVsp_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_vPDozOK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KWy6EVPH_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C6MCOhE1, 2, m, &cDelay_C6MCOhE1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AWecYxmp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NOitcVsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_vPDozOK1, 0, m, &hTable_vPDozOK1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oShllf7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_ArPdA94j_sendMessage);
}

void Heavy_ChaffVerb::cMsg_83WOeBlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_vPDozOK1, 0, m, &hTable_vPDozOK1_sendMessage);
}

void Heavy_ChaffVerb::cCast_AWecYxmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_C6MCOhE1, 0, m, &cDelay_C6MCOhE1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KWy6EVPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_hOOeF0PL, 2, m, &cDelay_hOOeF0PL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7qE1Z631_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_DDd7aiF4, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_rGnPWbvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GfEfYOvP, HV_BINOP_SUBTRACT, 0, m, &cBinop_GfEfYOvP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XFARZ4Gc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pYawC592_sendMessage);
}

void Heavy_ChaffVerb::cSystem_pYawC592_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9Zw9p5RU_sendMessage);
}

void Heavy_ChaffVerb::cVar_jbI9yj8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l4DrZ9I8_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_9KR5KSd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9KR5KSd4, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wajJqACn, 0, m, &cDelay_wajJqACn_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Lq4BFU9g, 0, m, &sTabread_Lq4BFU9g_sendMessage);
}

void Heavy_ChaffVerb::cDelay_wajJqACn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wajJqACn, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Lq4BFU9g, 0, m, &sTabread_Lq4BFU9g_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wajJqACn, 0, m, &cDelay_wajJqACn_sendMessage);
}

void Heavy_ChaffVerb::sTabread_Lq4BFU9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Vw8WsQxj, HV_BINOP_SUBTRACT, 0, m, &cBinop_Vw8WsQxj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_KYxLqhHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nb4R9Ux3, HV_BINOP_MAX, 0, m, &cBinop_Nb4R9Ux3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9Zw9p5RU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KYxLqhHI, HV_BINOP_MULTIPLY, 0, m, &cBinop_KYxLqhHI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GfEfYOvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HN2PVYfG_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Lq4BFU9g, 0, m, &sTabread_Lq4BFU9g_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1NIF3SlV_sendMessage);
}

void Heavy_ChaffVerb::cSystem_VeKuXy28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vw8WsQxj, HV_BINOP_SUBTRACT, 1, m, &cBinop_Vw8WsQxj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wajJqACn, 2, m, &cDelay_wajJqACn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_l4DrZ9I8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VeKuXy28_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HN2PVYfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9KR5KSd4, 0, m, &cDelay_9KR5KSd4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wajJqACn, 0, m, &cDelay_wajJqACn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_r7AAEg9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nb4R9Ux3, HV_BINOP_MAX, 1, m, &cBinop_Nb4R9Ux3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Nb4R9Ux3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GfEfYOvP, HV_BINOP_SUBTRACT, 1, m, &cBinop_GfEfYOvP_sendMessage);
}

void Heavy_ChaffVerb::cCast_1NIF3SlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9KR5KSd4, 0, m, &cDelay_9KR5KSd4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sx5lKXi5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9KR5KSd4, 2, m, &cDelay_9KR5KSd4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Vw8WsQxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_sx5lKXi5_sendMessage);
}

void Heavy_ChaffVerb::cCast_tEqTAEoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jbI9yj8g, 0, m, &cVar_jbI9yj8g_sendMessage);
  cMsg_XFARZ4Gc_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_rGnPWbvR, 0, m, &cTabhead_rGnPWbvR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pRU39nXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GO4WYY8L_sendMessage);
}

void Heavy_ChaffVerb::cSystem_GO4WYY8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_MFVqNLkU_sendMessage);
}

void Heavy_ChaffVerb::cDelay_FdPMOmen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FdPMOmen, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_eaJ4cG0Y, 0, m, &cDelay_eaJ4cG0Y_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FdPMOmen, 0, m, &cDelay_FdPMOmen_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Jnxbzqrv, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_eaJ4cG0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eaJ4cG0Y, m);
  cMsg_uhYsQNmZ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_YGVvd4gh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_rP2jzXlA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_066Nvgr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OJEXY2xw_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_txUpzsPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7NYRtneE_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FdPMOmen, 2, m, &cDelay_FdPMOmen_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9XpjrCrO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OJEXY2xw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_txUpzsPV, 0, m, &hTable_txUpzsPV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MFVqNLkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_066Nvgr5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uhYsQNmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_txUpzsPV, 0, m, &hTable_txUpzsPV_sendMessage);
}

void Heavy_ChaffVerb::cCast_9XpjrCrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FdPMOmen, 0, m, &cDelay_FdPMOmen_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7NYRtneE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_eaJ4cG0Y, 2, m, &cDelay_eaJ4cG0Y_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rP2jzXlA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Jnxbzqrv, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_1wfFsth5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PxFxd5Tz, HV_BINOP_SUBTRACT, 0, m, &cBinop_PxFxd5Tz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_c0JXtzfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IVUKow9t_sendMessage);
}

void Heavy_ChaffVerb::cSystem_IVUKow9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_XXooLmny_sendMessage);
}

void Heavy_ChaffVerb::cVar_P7oOt6IS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xNNA3uRd_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_tAVQTxnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tAVQTxnX, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6DMPrPpa, 0, m, &cDelay_6DMPrPpa_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OkwVgRT5, 0, m, &sTabread_OkwVgRT5_sendMessage);
}

void Heavy_ChaffVerb::cDelay_6DMPrPpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6DMPrPpa, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OkwVgRT5, 0, m, &sTabread_OkwVgRT5_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6DMPrPpa, 0, m, &cDelay_6DMPrPpa_sendMessage);
}

void Heavy_ChaffVerb::sTabread_OkwVgRT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_IgX2paaP, HV_BINOP_SUBTRACT, 0, m, &cBinop_IgX2paaP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_QPh0vIJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pWUKyF8S, HV_BINOP_MAX, 0, m, &cBinop_pWUKyF8S_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XXooLmny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QPh0vIJm, HV_BINOP_MULTIPLY, 0, m, &cBinop_QPh0vIJm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PxFxd5Tz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iQKtLgvI_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OkwVgRT5, 0, m, &sTabread_OkwVgRT5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gxP7tdhj_sendMessage);
}

void Heavy_ChaffVerb::cSystem_qLSwvCyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IgX2paaP, HV_BINOP_SUBTRACT, 1, m, &cBinop_IgX2paaP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6DMPrPpa, 2, m, &cDelay_6DMPrPpa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xNNA3uRd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qLSwvCyt_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iQKtLgvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tAVQTxnX, 0, m, &cDelay_tAVQTxnX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6DMPrPpa, 0, m, &cDelay_6DMPrPpa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VbkTr6Gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_pWUKyF8S, HV_BINOP_MAX, 1, m, &cBinop_pWUKyF8S_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pWUKyF8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PxFxd5Tz, HV_BINOP_SUBTRACT, 1, m, &cBinop_PxFxd5Tz_sendMessage);
}

void Heavy_ChaffVerb::cCast_gxP7tdhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tAVQTxnX, 0, m, &cDelay_tAVQTxnX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_g8OCs4wM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tAVQTxnX, 2, m, &cDelay_tAVQTxnX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IgX2paaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_g8OCs4wM_sendMessage);
}

void Heavy_ChaffVerb::cCast_khn7ywX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P7oOt6IS, 0, m, &cVar_P7oOt6IS_sendMessage);
  cMsg_c0JXtzfx_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_1wfFsth5, 0, m, &cTabhead_1wfFsth5_sendMessage);
}

void Heavy_ChaffVerb::cVar_0Br73mqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_l18xolK5, 0, m, &cVar_l18xolK5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Sosyff7K, 0, m, &cVar_Sosyff7K_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mFtGvgxo, 0, m, &cVar_mFtGvgxo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_j4QpksgS, 0, m, &cVar_j4QpksgS_sendMessage);
}

void Heavy_ChaffVerb::cVar_BCpIrUv0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_nHF8GeFh_sendMessage);
}

void Heavy_ChaffVerb::cPack_5PGVfP3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_84YJHH5v, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_Sosyff7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f5JM40rC, HV_BINOP_MULTIPLY, 0, m, &cBinop_f5JM40rC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_eyh4mbJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SjB86Zjs_sendMessage);
}

void Heavy_ChaffVerb::cSystem_SjB86Zjs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DXMOh2As_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_f5JM40rC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rD1pyelN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bXJfiFGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f5JM40rC, HV_BINOP_MULTIPLY, 1, m, &cBinop_f5JM40rC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DXMOh2As_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bXJfiFGP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rD1pyelN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_6qRRk8SY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6qRRk8SY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_uWvGw9Tn_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_A4lRuYRx, m);
}

void Heavy_ChaffVerb::cBinop_uWvGw9Tn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rlnKNXuQ, m);
}

void Heavy_ChaffVerb::cVar_mFtGvgxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cxZZMx5J, HV_BINOP_MULTIPLY, 0, m, &cBinop_cxZZMx5J_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QRxcZW1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_b6CppYNU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_b6CppYNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kaljJ13k_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_cxZZMx5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_cQcXuNX1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ttDPDEmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cxZZMx5J, HV_BINOP_MULTIPLY, 1, m, &cBinop_cxZZMx5J_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kaljJ13k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ttDPDEmP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cQcXuNX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_FspE89af_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FspE89af_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_YxXQ7j8s_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_vruzbMdq, m);
}

void Heavy_ChaffVerb::cBinop_YxXQ7j8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_JIzMvRoq, m);
}

void Heavy_ChaffVerb::cVar_j4QpksgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hBUEOzfB, HV_BINOP_MULTIPLY, 0, m, &cBinop_hBUEOzfB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZheHodIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fmMu1o7G_sendMessage);
}

void Heavy_ChaffVerb::cSystem_fmMu1o7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y6Sp4j4v_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_hBUEOzfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_WtNe21VV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MWyRwxOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hBUEOzfB, HV_BINOP_MULTIPLY, 1, m, &cBinop_hBUEOzfB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_y6Sp4j4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MWyRwxOA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WtNe21VV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_L07ySDIJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_L07ySDIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_eNo26pLt_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_MwTAystm, m);
}

void Heavy_ChaffVerb::cBinop_eNo26pLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qpdtmYPX, m);
}

void Heavy_ChaffVerb::cBinop_Zmraf37m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_PQFiP9kx, 0, m, &cPack_PQFiP9kx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_oep2mXqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_0Br73mqd, 0, m, &cVar_0Br73mqd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nHF8GeFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_5PGVfP3j, 0, m, &cPack_5PGVfP3j_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gB6n6uLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_L03sZepT, 0, m, &cPack_L03sZepT_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_7hAJWwub_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_nH5084De_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_nH5084De_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BELnjGB1_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_x1nWPBEA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_x1nWPBEA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_x1nWPBEA, 0, m, &cDelay_x1nWPBEA_sendMessage);
  cSwitchcase_NSwzd9u9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_BELnjGB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nH5084De_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_x1nWPBEA, 0, m, &cDelay_x1nWPBEA_sendMessage);
  cSwitchcase_NSwzd9u9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_4yoEobQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_szoXvEX4_sendMessage);
}

void Heavy_ChaffVerb::cSystem_szoXvEX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_zamNuggz_sendMessage);
}

void Heavy_ChaffVerb::cVar_hSakqM93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2AyaEYOj, HV_BINOP_MULTIPLY, 0, m, &cBinop_2AyaEYOj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nH5084De_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_x1nWPBEA, 0, m, &cDelay_x1nWPBEA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fE1Yi9kt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_x1nWPBEA, 2, m, &cDelay_x1nWPBEA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zamNuggz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2AyaEYOj, HV_BINOP_MULTIPLY, 1, m, &cBinop_2AyaEYOj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2AyaEYOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_fE1Yi9kt_sendMessage);
}

void Heavy_ChaffVerb::cVar_o5OfGGrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_u1AtTQNR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_DWUmewii_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_WiXLEDr9_sendMessage);
}

void Heavy_ChaffVerb::cVar_RrBeYUmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qRi6Ewad_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_hhgbF70R, 0, m, &cIf_hhgbF70R_sendMessage);
}

void Heavy_ChaffVerb::cUnop_jGLoaRTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BSlSwIm3, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_BSlSwIm3_sendMessage);
}

void Heavy_ChaffVerb::cUnop_viL8WLxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BSlSwIm3, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_BSlSwIm3_sendMessage);
}

void Heavy_ChaffVerb::cIf_hhgbF70R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_viL8WLxs_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_jGLoaRTN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_qRi6Ewad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hhgbF70R, 1, m, &cIf_hhgbF70R_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UvvvUMqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Elf8qhLV_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Elf8qhLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2Wz0Z02U_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ZSlQ9OCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZSlQ9OCu, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IPrnNLZb, 0, m, &cDelay_IPrnNLZb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZSlQ9OCu, 0, m, &cDelay_ZSlQ9OCu_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9jHfFD4s, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_IPrnNLZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IPrnNLZb, m);
  cMsg_sVyQPEUK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_A2JOg15Y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_9UTl8pUL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_HXM0zpT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MJbZj0ay_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_JAMez6mH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BCTDBvCA_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZSlQ9OCu, 2, m, &cDelay_ZSlQ9OCu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5IfDCwMl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MJbZj0ay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_JAMez6mH, 0, m, &hTable_JAMez6mH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2Wz0Z02U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_HXM0zpT1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sVyQPEUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_JAMez6mH, 0, m, &hTable_JAMez6mH_sendMessage);
}

void Heavy_ChaffVerb::cCast_5IfDCwMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZSlQ9OCu, 0, m, &cDelay_ZSlQ9OCu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BCTDBvCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_IPrnNLZb, 2, m, &cDelay_IPrnNLZb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9UTl8pUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9jHfFD4s, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_U0UHf1yz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ygznpXmp, HV_BINOP_SUBTRACT, 0, m, &cBinop_ygznpXmp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MszV3MGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QXlcIyOC_sendMessage);
}

void Heavy_ChaffVerb::cSystem_QXlcIyOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_TQEyuIbl_sendMessage);
}

void Heavy_ChaffVerb::cVar_elqioPSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L3qofHDY_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_M1C8TJbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_M1C8TJbm, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nf9MXItr, 0, m, &cDelay_nf9MXItr_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_cwhz8vis, 0, m, &sTabread_cwhz8vis_sendMessage);
}

void Heavy_ChaffVerb::cDelay_nf9MXItr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nf9MXItr, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_cwhz8vis, 0, m, &sTabread_cwhz8vis_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nf9MXItr, 0, m, &cDelay_nf9MXItr_sendMessage);
}

void Heavy_ChaffVerb::sTabread_cwhz8vis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_JkpeHpZw, HV_BINOP_SUBTRACT, 0, m, &cBinop_JkpeHpZw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_L1rGFrrx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yKe8bL0k, HV_BINOP_MAX, 0, m, &cBinop_yKe8bL0k_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TQEyuIbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L1rGFrrx, HV_BINOP_MULTIPLY, 0, m, &cBinop_L1rGFrrx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ygznpXmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IkPUpR24_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_cwhz8vis, 0, m, &sTabread_cwhz8vis_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5ETuaHxH_sendMessage);
}

void Heavy_ChaffVerb::cSystem_eOKNwV0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JkpeHpZw, HV_BINOP_SUBTRACT, 1, m, &cBinop_JkpeHpZw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nf9MXItr, 2, m, &cDelay_nf9MXItr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_L3qofHDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eOKNwV0d_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IkPUpR24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_M1C8TJbm, 0, m, &cDelay_M1C8TJbm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nf9MXItr, 0, m, &cDelay_nf9MXItr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EG040oDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_yKe8bL0k, HV_BINOP_MAX, 1, m, &cBinop_yKe8bL0k_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yKe8bL0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ygznpXmp, HV_BINOP_SUBTRACT, 1, m, &cBinop_ygznpXmp_sendMessage);
}

void Heavy_ChaffVerb::cCast_5ETuaHxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_M1C8TJbm, 0, m, &cDelay_M1C8TJbm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LGevCkzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_M1C8TJbm, 2, m, &cDelay_M1C8TJbm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JkpeHpZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_LGevCkzp_sendMessage);
}

void Heavy_ChaffVerb::cCast_4ByjD5JE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_elqioPSN, 0, m, &cVar_elqioPSN_sendMessage);
  cMsg_MszV3MGJ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_U0UHf1yz, 0, m, &cTabhead_U0UHf1yz_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_QETJjNCt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2X5jHmJz_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_2X5jHmJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MFKySz1y_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_kXBD1Iql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ENm51JDy, HV_BINOP_ADD, 0, m, &cBinop_ENm51JDy_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_sgXmrm5G_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HOYIG19r_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_HOYIG19r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eNYgAauy_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_TtaVeKkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k8eJrMoV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RbSQ5mVg_sendMessage);
}

void Heavy_ChaffVerb::cVar_T0YoAxYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BdVYQilN, 0, m, &cVar_BdVYQilN_sendMessage);
}

void Heavy_ChaffVerb::cVar_BdVYQilN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3eBKxwqB, HV_BINOP_ADD, 0, m, &cBinop_3eBKxwqB_sendMessage);
}

void Heavy_ChaffVerb::cVar_54ndX7JH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hudb3tQE, HV_BINOP_ADD, 0, m, &cBinop_hudb3tQE_sendMessage);
}

void Heavy_ChaffVerb::cVar_yTg8OlgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2L94DwVk_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_SzQQ5bpu, 0, m, &cIf_SzQQ5bpu_sendMessage);
}

void Heavy_ChaffVerb::cUnop_vTJ5QNJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hudb3tQE, HV_BINOP_ADD, 1, m, &cBinop_hudb3tQE_sendMessage);
}

void Heavy_ChaffVerb::cUnop_Pht8jFiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hudb3tQE, HV_BINOP_ADD, 1, m, &cBinop_hudb3tQE_sendMessage);
}

void Heavy_ChaffVerb::cIf_SzQQ5bpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_Pht8jFiv_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_vTJ5QNJB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_2L94DwVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SzQQ5bpu, 1, m, &cIf_SzQQ5bpu_sendMessage);
}

void Heavy_ChaffVerb::cVar_MQew5eT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qCWBLwYs_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_AbU2pxTx, 0, m, &cIf_AbU2pxTx_sendMessage);
}

void Heavy_ChaffVerb::cUnop_xa7iulBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CO4pbqqR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_bH8NVIL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CO4pbqqR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_AbU2pxTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_bH8NVIL5_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_xa7iulBC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_qCWBLwYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AbU2pxTx, 1, m, &cIf_AbU2pxTx_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_CO4pbqqR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cg3iAZsb, 0, m, &cSlice_cg3iAZsb_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lxAfixgD, 0, m, &cSlice_lxAfixgD_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AQZ9w47z_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d5gtlF5l_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_cg3iAZsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_TZaQ4lMH, 0, m, &cVar_TZaQ4lMH_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_TZaQ4lMH, 0, m, &cVar_TZaQ4lMH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_lxAfixgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_hwkBv5n6, HV_BINOP_NEQ, 1, m, &cBinop_hwkBv5n6_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_TZaQ4lMH, 1, m, &cVar_TZaQ4lMH_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_hwkBv5n6, HV_BINOP_NEQ, 1, m, &cBinop_hwkBv5n6_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_TZaQ4lMH, 1, m, &cVar_TZaQ4lMH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_TZaQ4lMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3zlXojcy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hZv5wG4u_sendMessage);
}

void Heavy_ChaffVerb::cIf_vcOhUZPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h27BpH2g_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ufdoxtmh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_h27BpH2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hwkBv5n6, HV_BINOP_NEQ, 1, m, &cBinop_hwkBv5n6_sendMessage);
}

void Heavy_ChaffVerb::cCast_Ufdoxtmh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TZaQ4lMH, 0, m, &cVar_TZaQ4lMH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hwkBv5n6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vcOhUZPs, 1, m, &cIf_vcOhUZPs_sendMessage);
}

void Heavy_ChaffVerb::cCast_AQZ9w47z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hwkBv5n6, HV_BINOP_NEQ, 0, m, &cBinop_hwkBv5n6_sendMessage);
}

void Heavy_ChaffVerb::cCast_d5gtlF5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vcOhUZPs, 0, m, &cIf_vcOhUZPs_sendMessage);
}

void Heavy_ChaffVerb::cIf_QBoDI2NG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_T0YoAxYO, 0, m, &cVar_T0YoAxYO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_7DY1HdZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_QBoDI2NG, 0, m, &cIf_QBoDI2NG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_LxqzgTxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_QBoDI2NG, 0, m, &cIf_QBoDI2NG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_x5dnksIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_QBoDI2NG, 0, m, &cIf_QBoDI2NG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_WuQs2qI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_TtaVeKkP, 0, m, &cVar_TtaVeKkP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_x6IfLyUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_54ndX7JH, 0, m, &cVar_54ndX7JH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lL8JFIiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_7DY1HdZE, 1, m, &cIf_7DY1HdZE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_niAFxcPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_x5dnksIx, 1, m, &cIf_x5dnksIx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TTGdZrAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_7DY1HdZE, 1, m, &cIf_7DY1HdZE_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_LxqzgTxs, 1, m, &cIf_LxqzgTxs_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_x5dnksIx, 1, m, &cIf_x5dnksIx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fwkTBKn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kXBD1Iql, 0, m, &cVar_kXBD1Iql_sendMessage);
}

void Heavy_ChaffVerb::cBinop_phssu0qR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_fwkTBKn8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_eNYgAauy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_TtaVeKkP, 0, m, &cVar_TtaVeKkP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BSlSwIm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rr5vawxG, HV_BINOP_MULTIPLY, 0, m, &cBinop_rr5vawxG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WiXLEDr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BSlSwIm3, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_BSlSwIm3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HuVE1Axr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_LxqzgTxs, 1, m, &cIf_LxqzgTxs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hudb3tQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ltOQhE6m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WVZpahDh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0gPy52HJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8NNRIa7Y, 0, m, &cVar_8NNRIa7Y_sendMessage);
}

void Heavy_ChaffVerb::cCast_ltOQhE6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0gPy52HJ, HV_BINOP_ADD, 1, m, &cBinop_0gPy52HJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_WVZpahDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T0YoAxYO, 0, m, &cVar_T0YoAxYO_sendMessage);
}

void Heavy_ChaffVerb::cCast_hZv5wG4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0EXbdyvH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_3zlXojcy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TTGdZrAC_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_GwhmgjKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OqmMB7QP, 0, m, &cVar_OqmMB7QP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rr5vawxG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LxqzgTxs, 0, m, &cIf_LxqzgTxs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_U5RXwR5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x5dnksIx, 0, m, &cIf_x5dnksIx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Hi5UD8C0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ZKo2XtQk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_U5RXwR5x_sendMessage);
}

void Heavy_ChaffVerb::cBinop_u1AtTQNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_sDT4WqNP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sDT4WqNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Hi5UD8C0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DWUmewii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o5OfGGrB, 1, m, &cVar_o5OfGGrB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_o43cIf42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3lokLHSW, 0, m, &cVar_3lokLHSW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IkQNF3ti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hSakqM93, 0, m, &cVar_hSakqM93_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MFKySz1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_T0YoAxYO, 0, m, &cVar_T0YoAxYO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ENm51JDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V0V4NzNH, HV_BINOP_MULTIPLY, 0, m, &cBinop_V0V4NzNH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_V0V4NzNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WuQs2qI7, 0, m, &cIf_WuQs2qI7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cuHHyBjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0gPy52HJ, HV_BINOP_ADD, 0, m, &cBinop_0gPy52HJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_k8eJrMoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cuHHyBjo, HV_BINOP_ADD, 1, m, &cBinop_cuHHyBjo_sendMessage);
}

void Heavy_ChaffVerb::cCast_RbSQ5mVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T0YoAxYO, 0, m, &cVar_T0YoAxYO_sendMessage);
}

void Heavy_ChaffVerb::cCast_LyZiIu9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QBoDI2NG, 1, m, &cIf_QBoDI2NG_sendMessage);
}

void Heavy_ChaffVerb::cCast_O1PxUCko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_QETJjNCt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_f798wv8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kXBD1Iql, 0, m, &cVar_kXBD1Iql_sendMessage);
}

void Heavy_ChaffVerb::cCast_cED0GubQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V0V4NzNH, HV_BINOP_MULTIPLY, 1, m, &cBinop_V0V4NzNH_sendMessage);
}

void Heavy_ChaffVerb::cCast_Stzdv9zw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sgXmrm5G_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_y5jACfnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WuQs2qI7, 1, m, &cIf_WuQs2qI7_sendMessage);
}

void Heavy_ChaffVerb::cCast_VKX7tySQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ENm51JDy, HV_BINOP_ADD, 1, m, &cBinop_ENm51JDy_sendMessage);
}

void Heavy_ChaffVerb::cCast_h0JAdqMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kXBD1Iql, 0, m, &cVar_kXBD1Iql_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JeM1FE3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cuHHyBjo, HV_BINOP_ADD, 0, m, &cBinop_cuHHyBjo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3eBKxwqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JeM1FE3d, HV_BINOP_MULTIPLY, 0, m, &cBinop_JeM1FE3d_sendMessage);
}

void Heavy_ChaffVerb::cCast_faSJprqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T0YoAxYO, 0, m, &cVar_T0YoAxYO_sendMessage);
}

void Heavy_ChaffVerb::cCast_cvTkUjLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JeM1FE3d, HV_BINOP_MULTIPLY, 1, m, &cBinop_JeM1FE3d_sendMessage);
}

void Heavy_ChaffVerb::cCast_BCHPEheV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T0YoAxYO, 0, m, &cVar_T0YoAxYO_sendMessage);
}

void Heavy_ChaffVerb::cCast_r2iHQImZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3eBKxwqB, HV_BINOP_ADD, 1, m, &cBinop_3eBKxwqB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nhcP1KJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3zlXojcy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hZv5wG4u_sendMessage);
}

void Heavy_ChaffVerb::cReceive_qzJf6JPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Otal4Rm2_sendMessage(_c, 0, m);
  cMsg_rrqvLkjB_sendMessage(_c, 0, m);
  cMsg_p5kKzdGx_sendMessage(_c, 0, m);
  cMsg_8DS3aw8V_sendMessage(_c, 0, m);
  cMsg_Cdyjl7D8_sendMessage(_c, 0, m);
  cMsg_pRU39nXs_sendMessage(_c, 0, m);
  cMsg_WDyGCps6_sendMessage(_c, 0, m);
  cMsg_h5ZfUkyl_sendMessage(_c, 0, m);
  cMsg_3BtDYzQC_sendMessage(_c, 0, m);
  cMsg_dzkZizOd_sendMessage(_c, 0, m);
  cMsg_1q5iAMK5_sendMessage(_c, 0, m);
  cMsg_5tUBN5BQ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_l18xolK5, 0, m, &cVar_l18xolK5_sendMessage);
  cMsg_eyh4mbJR_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Sosyff7K, 0, m, &cVar_Sosyff7K_sendMessage);
  cMsg_QRxcZW1Z_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_mFtGvgxo, 0, m, &cVar_mFtGvgxo_sendMessage);
  cMsg_ZheHodIV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_j4QpksgS, 0, m, &cVar_j4QpksgS_sendMessage);
  cMsg_gXDA5xkE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_wxbRyfFo, 0, m, &cVar_wxbRyfFo_sendMessage);
  cMsg_CdLjn5lv_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3lokLHSW, 0, m, &cVar_3lokLHSW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yv9hOr3S, 0, m, &cVar_yv9hOr3S_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OqmMB7QP, 0, m, &cVar_OqmMB7QP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NIqBN0fN, 0, m, &cVar_NIqBN0fN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SE81RVtH, 0, m, &cVar_SE81RVtH_sendMessage);
  cMsg_4yoEobQi_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_hSakqM93, 0, m, &cVar_hSakqM93_sendMessage);
  cMsg_UvvvUMqb_sendMessage(_c, 0, m);
  cSwitchcase_ZzJJruCe_onMessage(_c, NULL, 0, m, NULL);
  cMsg_MFKySz1y_sendMessage(_c, 0, m);
  cMsg_nhcP1KJB_sendMessage(_c, 0, m);
  cMsg_eNYgAauy_sendMessage(_c, 0, m);
  cSwitchcase_7hAJWwub_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_q6kq3Ubp, 0, m, &cVar_q6kq3Ubp_sendMessage);
  cMsg_54SvMGMJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_0KUY8ZEO, 0, m, &cVar_0KUY8ZEO_sendMessage);
  cMsg_jHzRnEmD_sendMessage(_c, 0, m);
  cMsg_En6XCdb2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_j51w71ej, 0, m, &cVar_j51w71ej_sendMessage);
  cMsg_srckXUuK_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vrtdTNeb, 0, m, &cTabhead_vrtdTNeb_sendMessage);
  cMsg_jLra77Nw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_TApWqnzX, 0, m, &cVar_TApWqnzX_sendMessage);
  cMsg_UsMx4d56_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_UBAUBOvl, 0, m, &cTabhead_UBAUBOvl_sendMessage);
  cMsg_laqWFmX0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_o2Go43DW, 0, m, &cVar_o2Go43DW_sendMessage);
  cMsg_GETqy3XJ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_mvgOoFRf, 0, m, &cTabhead_mvgOoFRf_sendMessage);
  cMsg_F4E5Pk94_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MDpLXs8q, 0, m, &cVar_MDpLXs8q_sendMessage);
  cMsg_0MbOij7d_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_MebRHg9W, 0, m, &cTabhead_MebRHg9W_sendMessage);
  cMsg_V9SZxp8C_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_voeK0Cvo, 0, m, &cVar_voeK0Cvo_sendMessage);
  cMsg_F30VkCpd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_1gMbtVIf, 0, m, &cTabhead_1gMbtVIf_sendMessage);
  cMsg_AfTfWCFT_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_hNop4w4J, 0, m, &cVar_hNop4w4J_sendMessage);
  cMsg_8YbGCUlP_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_2VtX2nvk, 0, m, &cTabhead_2VtX2nvk_sendMessage);
  cMsg_bNCQmAZS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_iBlM2YNM, 0, m, &cVar_iBlM2YNM_sendMessage);
  cMsg_kBF5yQkO_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_KuKDDAKy, 0, m, &cTabhead_KuKDDAKy_sendMessage);
  cMsg_hNEqMpan_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QCLevWjb, 0, m, &cVar_QCLevWjb_sendMessage);
  cMsg_LWjZxpYR_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_veAemnHH, 0, m, &cTabhead_veAemnHH_sendMessage);
  cMsg_r7AAEg9A_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jbI9yj8g, 0, m, &cVar_jbI9yj8g_sendMessage);
  cMsg_XFARZ4Gc_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_rGnPWbvR, 0, m, &cTabhead_rGnPWbvR_sendMessage);
  cMsg_VbkTr6Gl_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_P7oOt6IS, 0, m, &cVar_P7oOt6IS_sendMessage);
  cMsg_c0JXtzfx_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_1wfFsth5, 0, m, &cTabhead_1wfFsth5_sendMessage);
  cMsg_EG040oDP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_elqioPSN, 0, m, &cVar_elqioPSN_sendMessage);
  cMsg_MszV3MGJ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_U0UHf1yz, 0, m, &cTabhead_U0UHf1yz_sendMessage);
}

void Heavy_ChaffVerb::cReceive_RWrJN7yj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_o43cIf42_sendMessage);
}

void Heavy_ChaffVerb::cReceive_g9nB60eR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MQew5eT6, 0, m, &cVar_MQew5eT6_sendMessage);
}

void Heavy_ChaffVerb::cReceive_y89s2KcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RrBeYUmS, 0, m, &cVar_RrBeYUmS_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Np88CS64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rr5vawxG, HV_BINOP_MULTIPLY, 1, m, &cBinop_rr5vawxG_sendMessage);
}

void Heavy_ChaffVerb::cReceive_hcR6sVxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r2iHQImZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BCHPEheV_sendMessage);
}

void Heavy_ChaffVerb::cReceive_LptUNHrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cvTkUjLH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_faSJprqN_sendMessage);
}

void Heavy_ChaffVerb::cReceive_UXF8HLKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_54ndX7JH, 0, m, &cVar_54ndX7JH_sendMessage);
}

void Heavy_ChaffVerb::cReceive_rCTKJLa3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x6IfLyUi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yTg8OlgU, 0, m, &cVar_yTg8OlgU_sendMessage);
}

void Heavy_ChaffVerb::cReceive_3S76Dqtw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_IkQNF3ti_sendMessage);
}

void Heavy_ChaffVerb::cReceive_UJYKIeBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VKX7tySQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h0JAdqMi_sendMessage);
}

void Heavy_ChaffVerb::cReceive_3zQ4OCSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cED0GubQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f798wv8y_sendMessage);
}

void Heavy_ChaffVerb::cReceive_iZedKVwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y5jACfnX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Stzdv9zw_sendMessage);
}

void Heavy_ChaffVerb::cReceive_JrThWtRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XTMT3cTY, m);
}

void Heavy_ChaffVerb::cReceive_dTLssDxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_U4QKwSCH, m);
}

void Heavy_ChaffVerb::cReceive_GG0nQnZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yv9hOr3S, 0, m, &cVar_yv9hOr3S_sendMessage);
}

void Heavy_ChaffVerb::cReceive_hIj3NGVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_GwhmgjKE_sendMessage);
}

void Heavy_ChaffVerb::cReceive_yM8UVwgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QUfu7EPl, 0, m, &cVar_QUfu7EPl_sendMessage);
}

void Heavy_ChaffVerb::cReceive_PhB6hpe2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X61L4Xql, 0, m, &cVar_X61L4Xql_sendMessage);
}

void Heavy_ChaffVerb::cReceive_kOZMDCap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wxbRyfFo, 0, m, &cVar_wxbRyfFo_sendMessage);
}

void Heavy_ChaffVerb::cReceive_un3WBGgJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Du99ZcVc, m);
}

void Heavy_ChaffVerb::cReceive_lB4cQQoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Bb40zEgq, m);
}

void Heavy_ChaffVerb::cReceive_vcYOh2sI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L1rGFrrx, HV_BINOP_MULTIPLY, 1, m, &cBinop_L1rGFrrx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4ByjD5JE_sendMessage);
}

void Heavy_ChaffVerb::cReceive_W3bUhQDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LyZiIu9C_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O1PxUCko_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_XP3gf8Xc, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_W0S3zo6T, VOf(Bf4));
    __hv_line_f(&sLine_pt55X9SE, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_SyekcpK0, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_27eG82Sn, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_BU9Bd5lz, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_lyO5EoeL, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_sUPQOFs0, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_91VkU3O8, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_OmYRX0J9, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_Uz0pXEA5, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_vSvusw1r, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_wzhbASVN, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_yGtZyqPp, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_mlhDATqp, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_G7GNzQsX, VIf(I0));
    __hv_varread_f(&sVarf_ViOOKQ9O, VOf(Bf2));
    __hv_rpole_f(&sRPole_TN6XmZqs, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_GiFdu9KP, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_U3gUg70q, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_Du99ZcVc, VOf(Bf1));
    __hv_tabread_f(&sTabread_cwhz8vis, VOf(Bf5));
    __hv_varread_f(&sVarf_Bb40zEgq, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_9jHfFD4s, VIf(Bf9));
    __hv_varread_f(&sVarf_U4QKwSCH, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_QSCHG0IJ, VOf(Bf9));
    __hv_varread_f(&sVarf_6KEKAhKT, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_5YmX3rzA, VOf(Bf2));
    __hv_rpole_f(&sRPole_xkEzwnNR, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_84YJHH5v, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_F4Qdw6P6, VOf(Bf2));
    __hv_tabread_f(&sTabread_wTihnYjl, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_qE08cZ0T, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_hafWPAXo, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_4IVa2Ccu, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_OkwVgRT5, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_Lq4BFU9g, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_4d2bpFph, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_xADlMFnm, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_H1ADYMjs, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_3Dra1G18, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_DDd7aiF4, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_Jnxbzqrv, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_AooxjNXh, VOf(Bf9));
    __hv_varread_f(&sVarf_A4lRuYRx, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_rlnKNXuQ, VOf(Bf3));
    __hv_rpole_f(&sRPole_gxOvrWN8, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_3sWiG9ce, VOf(Bf3));
    __hv_varread_f(&sVarf_vruzbMdq, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_JIzMvRoq, VOf(Bf12));
    __hv_rpole_f(&sRPole_ls7iDhAw, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_LGbwZp1r, VOf(Bf12));
    __hv_varread_f(&sVarf_MwTAystm, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_qpdtmYPX, VOf(Bf11));
    __hv_rpole_f(&sRPole_qbURdhk3, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_F3uA3heL, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_VvCDIds8, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_qwpoaRyi, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_4C14w19W, VIf(Bf11));
    __hv_line_f(&sLine_LgBv0MbP, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_XTMT3cTY, VOf(Bf3));
    __hv_mul_f(VIf(I0), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf11), VIf(Bf3), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf13), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
